import React, { Component } from 'react'
import { connect } from 'react-redux'
import { Input, Row, message } from 'antd'
import _ from 'lodash'
import styles from './style.module.scss'
import {
  namespace as namespaceProductSpec,
  IProductSpecItem,
  IProductSpecItemPayload,
  actionType
} from '@/models/global/product-spec/index'

interface IProps {
  selectedProductSpectList?: IProductSpecItem[]
  dispatch?: any
  onRef?: any
  productItem: IProductSpecItem
  /** 是否为普通模式（普通模式：输入框输入后不会自动加入购物车），默认为普通模式  */
  isPlain: boolean
  /** disable 是否禁用，默认为 false */
  disable?: boolean
  /** 输入框改变时触发 */
  onChange: (inputValue) => void
  /** 输入框失去焦点时触发 */
  onBlur: (inputValue) => void
}
interface IState {
  inputValue: number
}
let updata = true // updata 是否更新最小购买量
class ProductSpec extends Component<Partial<IProps>, IState> {
  constructor(props) {
    super(props)
    const minByCount = this.props.productItem ? Number(this.props.productItem.minByCount) : 1 // 最小购买量
    this.state = {
      inputValue: minByCount
    }
  }

  componentDidMount() {
    // 通过pros接收父组件传来的方法
    if (this.props.onRef) {
      this.props.onRef(this)
    }
  }
  componentDidUpdate() {
    if (this.props.productItem && updata) {
      this.setState({ inputValue: Number(this.props.productItem.minByCount) })
      updata = false
    }
  }

  shouldComponentUpdate(nextProps, nextState) {
    const { productItem } = this.props
    if (!productItem) {
      return true
    }
    const shouldUpdate = productItem.goodsId === nextProps.currentChangedSelectedSpec.goodsId || nextState !== this.state
    if (shouldUpdate) {
      return true
    }
    return false
  }

  /**
   * 购物车加减处理
   */
  handleOperateProductSpec = operateType => {
    let { productItem } = this.props
    const { isPlain = true } = this.props
    const { inputValue } = this.state
    if (!productItem) {
      productItem = {} as IProductSpecItem
      productItem.minByCount = 1
      productItem.selectedCount = 0
    }
    const { minByCount, selectedCount } = productItem
    let inputValueTemp
    const payload: IProductSpecItemPayload = {
      ...productItem
    }
    // 判断最小操作数量
    const inputCalc = isPlain ? inputValue : selectedCount
    if (operateType === actionType.Decrease && inputCalc < 2) {
      return
    }

    if (operateType === actionType.Decrease) {
      if (inputCalc - 1 < minByCount) {
        inputValueTemp = minByCount
        message.warn(`最小购买量为${minByCount}`)
        return
      } else {
        inputValueTemp = inputCalc - 1
      }
    } else {
      if (inputCalc + 1 < minByCount) {
        inputValueTemp = minByCount
        message.warn(`最小购买量为${minByCount}`)
        return
      } else {
        inputValueTemp = inputCalc + 1
      }
    }

    // 如果为普通模式，则只改变输入框的数字，不改变购物车全局数据
    if (!isPlain) {
      this.props.dispatch({
        payload,
        operateType,
        type: `${namespaceProductSpec}/operateProductSpec`
      })
    } else {
      this.setState({
        inputValue: inputValueTemp
      })
    }
  }

  /**
   * 获取已选择数量
   */
  getSelectedCount = () => {
    const {
      selectedProductSpectList,
      productItem: { goodsId, specId }
    } = this.props
    if (selectedProductSpectList.length) {
      const selected = selectedProductSpectList.find(it => it.goodsId === goodsId && it.specId === specId)
      // 兼容删除情况
      return selected ? selected.selectedCount : 0
    }
    return 0
  }

  /**
   * 加入购物车
   */
  handleAddShoppingCart = () => {
    const { productItem, isPlain = true } = this.props
    const { inputValue } = this.state
    const payload: IProductSpecItemPayload = {
      isPlain,
      inputValue,
      ...productItem,
      isInput: true
    }
    // 判断最小购买量，针对于没有 productItem 情况
    const { minByCount } = productItem
    if (inputValue < minByCount) {
      this.setState({
        inputValue: Number(minByCount)
      })
      message.warn(`最小购买量为${minByCount}`)
      payload.inputValue = minByCount
    }
    this.props.dispatch({
      payload,
      type: `${namespaceProductSpec}/setProductSpecSelected`,
      callback: () => {
        if (this.props.isPlain) {
          const _minByCount = this.props.productItem ? Number(this.props.productItem.minByCount) : 1 // 最小购买量
          this.setState({
            inputValue: _minByCount
          })
        }
      }
    })
  }
  handleSelectCountInput = e => {
    if (!this.props.productItem) {
      message.warn(`请选择商品规格`)
      return
    }
    const { isPlain = true } = this.props
    if (!e.target) {
      return
    }
    const value = Number(e.target.value)
    if (value < 0 || isNaN(value)) {
      return
    }
    if (isPlain) {
      this.setState({
        inputValue: e.target.value
      })
      if (typeof this.props.onChange === 'function') {
        this.props.onChange(e.target.value)
      }
    } else {
      const { productItem } = this.props
      // tslint:disable-next-line
      const payload: IProductSpecItemPayload = {
        ...productItem,
        isPlain,
        inputValue: value,
        isInput: true
      }
      this.props.dispatch({
        payload,
        type: `${namespaceProductSpec}/setProductSpecSelected`
      })
    }
  }

  handleSelectCountBlur = e => {
    // 判断没有传入数据不执行
    if (!this.props.productItem) {
      return
    }

    // 判断最小购买量
    const { productItem, isPlain = true } = this.props
    let value = Number(e.target.value)
    if (value < productItem.minByCount) {
      value = Number(productItem.minByCount)
      message.warn(`最小购买量为${productItem.minByCount}`)
    }
    if (isPlain) {
      this.setState({
        inputValue: value
      })
      if (typeof this.props.onBlur === 'function') {
        this.props.onBlur(e.target.value)
      }
    } else {
      // tslint:disable-next-line
      const payload: IProductSpecItemPayload = {
        ...productItem,
        isPlain,
        inputValue: value,
        isInput: true
      }
      this.props.dispatch({
        payload,
        type: `${namespaceProductSpec}/setProductSpecSelected`
      })
    }
  }

  render() {
    const { inputValue } = this.state
    const { isPlain = true, disable = false } = this.props
    const selectedCount = this.props.productItem ? this.getSelectedCount() : null
    const showMinNum = isPlain ? inputValue : selectedCount // 减少购物车的最小数量

    const shoppingCartItem = (
      <Row className={styles.container}>
        {!disable && (
          <div
            className={`operate-item-icon ${showMinNum < 2 ? 'disabled' : ''}`}
            onClick={() => {
              this.handleOperateProductSpec(actionType.Decrease)
            }}
          >
            -
          </div>
        )}

        {isPlain ? (
          <Input
            size="small"
            value={inputValue}
            disabled={disable}
            className={styles.input}
            onBlur={this.handleSelectCountBlur}
            onChange={_.throttle(e => {
              this.handleSelectCountInput(e)
            }, 300)}
          />
        ) : (
          <Input
            size="small"
            disabled={disable}
            value={selectedCount === 0 ? '' : selectedCount}
            className={styles.input}
            onBlur={this.handleSelectCountBlur}
            onChange={_.throttle(e => {
              this.handleSelectCountInput(e)
            }, 300)}
          />
        )}
        {!disable && (
          <div
            className="operate-item-icon"
            onClick={() => {
              this.handleOperateProductSpec(actionType.Increase)
            }}
          >
            +
          </div>
        )}
      </Row>
    )
    return (
      <div style={{ display: 'flex', justifyContent: 'center' }}>{selectedCount > 0 ? shoppingCartItem : shoppingCartItem}</div>
    )
  }
}

const mapStateToProps = models => ({
  ...models[namespaceProductSpec]
})

export default connect(mapStateToProps)(ProductSpec)
