import React, { useState, useEffect, useRef } from 'react'
import { Layout, Menu } from 'antd'
import imgs from '@/assets/images'
import { MenuProps, namespace } from '@/models/common/side-menu'
import { connect } from 'react-redux'
import { IDispatch } from '@/models/connect'
import menus, { MenuItem } from './config'
import { Link, useHistory, useLocation } from 'react-router-dom'
import unionBy from 'lodash/unionBy'

const SubMenu = Menu.SubMenu

const Sider = Layout.Sider
interface IProps extends Partial<MenuProps>, IDispatch {}

function renderIco(ico: any) {
  if (!ico) {
    return null
  }
  return ico.render()
}

function findMenuByPath(menus: MenuItem[], path: string, keys: any[]) {
  for (const menu of menus) {
    if (menu.path === path) {
      return [...keys, menu.key]
    }
    if (menu.children && menu.children.length > 0) {
      const result = findMenuByPath(menu.children, path, [...keys, menu.key])
      if (result.length === 0) {
        continue
      }
      return result
    }
  }
  return []
}

// todo: 切换展开关闭时，openkeys会抖动一下，除非openkeys使用非受控组件

const SideMenus: React.FC<IProps> = ({ dispatch, collapsed, tabsList }) => {
  const [openKeys, setOpenKeys] = useState([]) // 打开的子菜单key
  const [selectedKeys, setSelectedKeys] = useState('') // 当前选中的菜单项key
  const [isFirst, setIsFirst] = useState(true) // 用于标识是否是首次渲染
  const backupOpenKeys = useRef([]) // 存储打开子菜单的备份
  const history = useHistory()
  const location = useLocation()
  // path和select keys双向绑定
  useEffect(() => {
    const keys: string[] = findMenuByPath(menus, location.pathname, [])
    if (keys.length) {
      setSelectedKeys(keys.pop())
      setOpenKeys([...openKeys, ...keys])
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [location.pathname])
  // 关闭菜单时保存当前openKeys
  useEffect(() => {
    // 只有首次渲染完成后，每次更改打开关闭状态才做下面的备份操作
    if (isFirst) {
      setIsFirst(false)
      return
    }
    if (collapsed) {
      backupOpenKeys.current = openKeys
      setOpenKeys([])
    } else {
      setOpenKeys(backupOpenKeys.current)
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [collapsed])
  function handleMenuClick(e: React.MouseEvent<HTMLAnchorElement>, menu: MenuItem) {
    e.preventDefault()
    dispatch({
      type: `${namespace}/setState`,
      payload: {
        tabsList: unionBy([...tabsList, menu], 'key')
      }
    })
    history.push(menu.path)
  }
  function handleOpenChange(openKeys: string[]) {
    setOpenKeys(openKeys)
  }
  function renderMenu(menus: MenuItem[]) {
    if (menus.length === 0) {
      return null
    }
    return menus.map(menu => {
      if (menu.children) {
        return (
          <SubMenu
            key={menu.key}
            title={
              <>
                {renderIco(menu.icon)}
                <span>{menu.title}</span>
              </>
            }
          >
            {renderMenu(menu.children)}
          </SubMenu>
        )
      }
      return (
        <Menu.Item key={menu.key} title={menu.title}>
          <Link to={menu.path} onClick={e => handleMenuClick(e, menu)}>
            {menu.title}
          </Link>
        </Menu.Item>
      )
    })
  }
  return (
    <Sider trigger={null} collapsible width={190} collapsed={collapsed}>
      {collapsed ? (
        <p style={{ textAlign: 'center', margin: '4px 0' }}>
          <img style={{ width: 'auto', height: '40px' }} src={imgs.WBDLogoS} alt="物必达logo" />
        </p>
      ) : (
        <img style={{ width: '160px', height: 'auto', marginTop: '10px' }} src={imgs.WBDLogo} alt="物必达logo" />
      )}
      <Menu openKeys={openKeys} selectedKeys={[selectedKeys]} theme="dark" mode="inline" onOpenChange={handleOpenChange}>
        {renderMenu(menus)}
      </Menu>
    </Sider>
  )
}

const mapStateToProps = models => ({
  ...models[namespace]
})

export default connect(mapStateToProps)(SideMenus)
