/* 商品规格，维护整个购物车数量 ，加减操作等*/
import _remove from 'lodash/remove'
import _cloneDeep from 'lodash/cloneDeep'
import { setLocalStorage, getLocalStorage } from '@/utils/storage/index'
import { message } from 'antd'
import { executeCallback } from '@/utils/tools'

/* 购物车每个规格商品类型 */
export interface IProductSpecItem {
  /** 商品id */
  goodsId?: number
  /** 商品图片 */
  goodsImage?: string
  /** 商品名称 */
  goodsName?: string
  /** 已选择数量 */
  selectedCount?: number
  /** 规格 id */
  specId?: number | string
  /** 规格价格 */
  price?: string
  /** 规格描述 */
  specDesc?: string
  /** 品牌 id  */
  goodsBrandId: number
  /** 品牌类型  motorbike 整车   parts  配件 */
  goodsBrandType?: string
  /** 最小购买数量  */
  minByCount?: string | number
  /** 供应商名称  */
  supplierName: string
  /** 按照用户分类 id */
  sellerBrandId: number
  /** 品牌 */
  sellerBrandName: string
  /** 货币符号 */
  moneySymbol?: string
  /** 供应商id */
  supplierId?: string | number
}

export interface IProductSpecItemPayload extends IProductSpecItem {
  /* 是否手动输入 */
  isInput?: boolean
  /* input 数量 */
  inputValue?: string | number
  /* isPlain 是否为普通模式*/
  isPlain?: boolean
}
export interface ICurrentChangedSelectedSpec {
  goodsId: string
  specId: string
}
export const namespace = 'product-spec'

// 操作类型
export enum actionType {
  Increase = 'Increase',
  Decrease = 'Decrease'
}
export let operateSpectType = actionType.Decrease // 操作类型
export interface IProductSpec {
  goodsId: number
  specId: number
}
export interface ISelectedProduct {
  goodsId: number
  specId: number
  selectedCount: number
}

// 获取 localstorage 中的数据
const selectedProductSpectListStorage = JSON.parse(getLocalStorage('shoppingCartListStorage') || '[]') || []
let increaseTimer = null
// 购物车数量
export let shoppingCartNum = 0
selectedProductSpectListStorage.forEach(item => {
  // 购物车数量
  shoppingCartNum += item.selectedCount
})
export default {
  namespace,
  state: {
    selectedProductSpectList: selectedProductSpectListStorage, // 已选择商品规格列表
    selectedOrderProductSpectList: [], // 下单选择的商品，用于下单
    currentChangedSelectedSpec: {} // 当前选择的商品，用于判断组件是否需要更新，防止点击一处加减，整个页面商品增加组件全部更新
  },
  effects: {
    /**
     *  处理购物车加减
     */
    *operateProductSpec(
      { payload, operateType } = {
        payload: {} as IProductSpecItemPayload,
        operateType: actionType.Increase
      },
      { put, select }
    ) {
      try {
        const { selectedProductSpectList } = yield select(state => state[namespace])
        const selectedIdList: IProductSpecItem[] = [...selectedProductSpectList]
        const { goodsId, specId } = payload
        const minByCountPayload = Number(payload.minByCount) || 1
        let obj = selectedIdList.find(it => it.goodsId === goodsId && it.specId === specId)
        if (!obj) {
          obj = {
            ...payload,
            selectedCount: 0
          }
          selectedIdList.push(obj)
        }
        operateSpectType = operateType
        // 新增操作
        if (operateSpectType === actionType.Increase) {
          // 处理最小购买量
          if (obj.selectedCount === 0 && minByCountPayload > 1) {
            shoppingCartNum += minByCountPayload
            obj.selectedCount += minByCountPayload
          } else {
            shoppingCartNum += 1
            obj.selectedCount += 1
          }

          // 购物车添加防抖
          clearTimeout(increaseTimer)
          increaseTimer = setTimeout(() => {
            message.success('成功加入购物车', 2)
          }, 1000)
        } else if (obj.selectedCount > 0) {
          // 处理最小购买量
          if (minByCountPayload > 1 && obj.selectedCount === minByCountPayload) {
            shoppingCartNum -= minByCountPayload
            obj.selectedCount -= minByCountPayload
          } else {
            shoppingCartNum -= 1
            obj.selectedCount -= 1
          }

          if (obj.selectedCount <= 0) {
            obj.selectedCount = 0
          }
          obj.selectedCount = obj.selectedCount < 0 ? 0 : obj.selectedCount
        }
        yield put({
          type: 'setState',
          payload: {
            currentChangedSelectedSpec: {
              goodsId,
              specId
            },
            selectedProductSpectList: JSON.parse(JSON.stringify(selectedIdList.filter(it => it.selectedCount > 0)))
          }
        })
      } catch (error) {}
    },

    /**
     *  处理手动添加数量
     */
    *setProductSpecSelected({ payload, callback } = { payload: {} as IProductSpecItemPayload, callback: null }, { put, select }) {
      try {
        const { selectedProductSpectList } = yield select(state => state[namespace])
        const selectedIdList: IProductSpecItem[] = [...selectedProductSpectList]
        const { goodsId, specId, inputValue, isPlain = true } = payload
        let selectObj = selectedIdList.find(it => it.goodsId === goodsId && it.specId === specId)
        const minByCountPayload = Number(payload.minByCount) || 0
        if (!selectObj) {
          shoppingCartNum += Math.max(Number(inputValue), minByCountPayload)
          selectObj = {
            ...payload,
            selectedCount: Math.max(Number(inputValue), minByCountPayload)
          }
          if (minByCountPayload > Number(inputValue)) {
            message.warn(`最小购买量为${minByCountPayload}`, 2)
          }
          selectedIdList.push(selectObj)
        } else {
          if (Number(inputValue) > selectObj.selectedCount) {
            // 购物车添加防抖
            clearTimeout(increaseTimer)
            increaseTimer = setTimeout(() => {
              message.success('成功加入购物车', 2)
            }, 1000)
          }
          /* shoppingCartNum += Math.max(Number(inputValue), minByCountPayload) - selectObj.selectedCount
          selectObj.selectedCount = Math.max(Number(inputValue), minByCountPayload) */

          if (isPlain) {
            clearTimeout(increaseTimer)
            increaseTimer = setTimeout(() => {
              message.success('成功加入购物车', 2)
            }, 1000)
            // 将原有的购物车数据加上
            selectObj.selectedCount = Number(inputValue) + Number(selectObj.selectedCount)
          } else {
            selectObj.selectedCount = Number(inputValue)
          }

          if (Number(inputValue) === 0) {
            // 删除的情况
            selectObj.selectedCount = 0
          }
        }
        yield put({
          type: 'setState',
          payload: {
            currentChangedSelectedSpec: {
              goodsId,
              specId
            },
            selectedProductSpectList: JSON.parse(JSON.stringify(selectedIdList))
          }
        })
        executeCallback(callback)
      } catch (error) {}
    },

    /**
     *  删除购物车中的商品
     */
    *deleteProductSpecSelected({ payload } = { payload: {} as IProductSpecItemPayload }, { put, select }) {
      try {
        const { selectedProductSpectList } = yield select(state => state[namespace])
        const selectedIdList: IProductSpecItem[] = [...selectedProductSpectList]
        const { goodsId, specId } = payload
        _remove(selectedIdList, item => {
          return item.goodsId === goodsId && item.specId === specId
        })
        yield put({
          type: 'setState',
          payload: {
            currentChangedSelectedSpec: {
              goodsId,
              specId
            },
            selectedProductSpectList: _cloneDeep(selectedIdList.filter(it => it.selectedCount > 0))
          }
        })
        return true
      } catch (error) {
        return false
      }
    },

    /**
     * 批量删除购物车中的商品
     */
    *deleteProductSpecSelectedByBatch({ payload } = { payload: [] as IProductSpecItemPayload[] }, { put, select }) {
      try {
        const { selectedProductSpectList } = yield select(state => state[namespace])
        const selectedIdList: IProductSpecItem[] = [...selectedProductSpectList]
        payload.forEach(item => {
          const { goodsId, specId } = item
          _remove(selectedIdList, itemOrigin => {
            return itemOrigin.goodsId === goodsId && itemOrigin.specId === specId
          })
        })
        yield put({
          type: 'setState',
          payload: {
            selectedProductSpectList: _cloneDeep(selectedIdList.filter(it => it.selectedCount > 0))
          }
        })
        return true
      } catch (error) {
        return false
      }
    },

    /**
     * 设置购物车
     * just for test
     */
    *setMockSelect({ payload } = { payload: {} as IProductSpecItemPayload }, { put }) {
      yield put({
        type: 'setState',
        payload: {
          selectedProductSpectList: payload
        }
      })
    },

    /**
     * 刷新购物车
     */

    *refreshList(_, { put }) {
      yield put({
        type: 'setState',
        payload: {
          selectedProductSpectList: JSON.parse(getLocalStorage('shoppingCartListStorage')) || []
        }
      })
    },

    /**
     * 清空购物车
     */
    *clearShoppingCartList(_, { put }) {
      yield put({
        type: 'setState',
        payload: {
          selectedProductSpectList: [],
          selectedOrderProductSpectList: [],
          currentChangedSelectedSpec: {}
        }
      })
    }
  },
  reducers: {
    setState(state, { payload }) {
      const { selectedProductSpectList } = payload
      if (selectedProductSpectList) {
        // 保存在 localstorage 中，防止刷新页面数据清空
        setLocalStorage('shoppingCartListStorage', JSON.stringify(selectedProductSpectList))
      }
      return { ...state, ...payload }
    }
  }
}
