import { getLastAddressId } from '@/services/mods/merchProcurementOrder/getLastAddressId'
import { listBuyerAddress } from '@/services/mods/merchProcurementOrder/listBuyerAddress'
import { createOrder } from '@/services/mods/merchProcurementOrder/createOrder'
export const namespace = 'purchase-module-order-confirm'

export interface IDvaState {
  lastAddressId: string
  addressList: defs.UBuyerAddressResponse[]
}

const state: IDvaState = {
  lastAddressId: '',
  addressList: []
}
export default {
  namespace,
  state,
  effects: {
    // 初始化页面数据
    *init({ payload }, { put }) {
      yield put({ type: 'getLastAddressId' })
      yield put({ type: 'listBuyerAddress' })
    },
    /**
     * 获取上次下单地址ID
     */
    *getLastAddressId(_, { put, call }) {
      try {
        const result = yield call(getLastAddressId)
        yield put({
          type: 'setState',
          payload: { lastAddressId: result.data }
        })
      } catch (error) {}
    },
    /**
     * 下单
     */
    *createOrder({ payload, callback }, { put, call }) {
      try {
        const result = yield call(createOrder, { bodyParams: payload })
        if (result) {
          callback(result)
        }
      } catch (error) {}
    },
    /**
     * 用户配送地址列表
     */
    *listBuyerAddress(_, { put, call }) {
      try {
        const result = yield call(listBuyerAddress)
        yield put({
          type: 'setState',
          payload: { addressList: result }
        })
      } catch (error) {}
    }
  },
  reducers: {
    setState(state, { payload }) {
      return { ...state, ...payload }
    }
  }
}
