import { moduleCode } from '../module'
import { detail, IParams } from '@/services/mods/goods/detail'
import {
  GoodsInfoProductResp,
  GoodsInfoAttributeSpecOptionProductResp,
  GoodsInfoAttributeSpecProductResp,
  GoodsInfoSpecProductResp,
  GoodsInfoProductRespEntity
} from './type'

const moduleName = 'product-detail'
export const namespace = `${moduleCode}-${moduleName}`

export interface IDvaState {
  detailInfo: GoodsInfoProductResp
  selectedSpecOptionObj: any
}
const state: IDvaState = {
  detailInfo: new GoodsInfoProductRespEntity(),
  selectedSpecOptionObj: {}
}

export default {
  namespace,
  state,
  effects: {
    *query({ payload }, { call, put }) {
      try {
        const params: IParams = {
          queryParams: payload
        }
        const re = yield call(detail, params)
        const _result: defs.GoodsInfoResponse = re.data
        const attributeSpecOptions: GoodsInfoAttributeSpecOptionProductResp[] = _result.specAttrList.reduce((pr, cur) => {
          const currentArrs: GoodsInfoAttributeSpecOptionProductResp[] = cur.values.map(c => {
            const r: GoodsInfoAttributeSpecOptionProductResp = {
              goodsId: c.goodsId,
              optionRank: c.sort,
              templateSpecId: c.specAttrId,
              templateSpecOptionId: c.id,
              templateSpecOptionName: c.valueName,
              attributeSpecOptionImge: ''
            }
            return r
          })
          return [...pr, ...currentArrs]
        }, [])
        const attributeSpecs: GoodsInfoAttributeSpecProductResp[] = _result.specAttrList.map(item => {
          const r: GoodsInfoAttributeSpecProductResp = {
            goodsId: _result.id,
            specRank: item.sort,
            templateSpecId: item.id,
            templateSpecSpecName: item.name
          }
          return r
        })
        const specs: GoodsInfoSpecProductResp[] = _result.goodsInfoSpecResponses
          .filter(item => item.sell)
          .map((item: any) => {
            const r: GoodsInfoSpecProductResp = {
              brandId: _result.brandId,
              categoryId: _result.categoryId,
              goodsId: _result.id,
              goodsName: _result.name,
              moneySymbol: '￥',
              price: item.guidePrice,
              ladderPrice: item.ladderPrice,
              specId: item.id,
              specName: item.name,
              specOptionCode: item.specOptionCode,
              stockQuantity: 99999999,
              thirdCode: item.specCode,
              purchasePrice: item.purchasePrice,
              guidePrice: item.guidePrice
            }
            return r
          })
        const result: GoodsInfoProductResp = {
          attributeSpecOptions,
          attributeSpecs,
          basicConf: [_result.recommend],
          canBuy: _result.onState === 1 && _result.status === 1,
          carousel: _result.wheelImage,
          goodsBrandId: _result.brandId,
          goodsId: _result.id,
          goodsImage: _result.mainImage,
          goodsName: _result.name,
          goodsRemark: _result.details,
          goodsUnit: _result.unitName,
          hasSpecRes: true,
          minBuyCount: _result.minNumber || 1,
          // miniPrice: _result.priceStart.toString(),
          //以下字段未使用
          moneySymbol: _result.currencySymbol,
          onlineState: _result.onState === 1,
          openStock: false,
          produceDay: 3,
          remarkImages: [],
          //以上字段未使用
          sellerBrandId: _result.brandId,
          sellerBrandName: _result.brandName,
          supplierId: _result.supplierId,
          sellerName: _result.supplierName,
          supplierName: _result.supplierName,
          specs,
          purchasePrice: _result.price,
          guidePrice: _result.guidePrice
        }
        const { remarkImages: _remarkImages } = result
        // yield put(
        //   NavigationActions.setParams({
        //     key: purchaseRouters.ProductDetailPage,
        //     params: {
        //       title: goodsName
        //     }
        //   })
        // )
        const mapSpecs = specs.map(it => ({
          ...it,
          quantity: 1
        }))
        const len = specs.length
        // 遍历具体每个spec，去specs list中的specOptionCode字段查询是否存在当前遍历的spec
        const mapAttributeSpecOptions = attributeSpecOptions.map(item => {
          // 用for循环 是因为找到符合条件后 直接return终止循环，也可以使用forEach，thorw error 然后try catch来中断循环。
          for (let i = 0; i < len; i += 1) {
            // '1,2,3,6,7'
            const { specOptionCode } = specs[i]
            // templateSpecOptionIds数组,['1','3','24']
            const it = specOptionCode.split(',')
            if (it.find(q => q === item.templateSpecOptionId.toString())) {
              // 找到就直接返回 说明可以选择
              return {
                ...item,
                canSelect: true
              }
            }
          }
          return {
            ...item,
            canSelect: false
          }
        })
        const mapAttributeSpecs = attributeSpecs
          .sort((a, b) => a.specRank - b.specRank)
          .map(item => {
            const options = mapAttributeSpecOptions
              .filter(it => it.templateSpecId === item.templateSpecId)
              .sort((a, b) => a.optionRank - b.optionRank)
            return {
              ...item,
              options
            }
          })
        const detailInfo = {
          ...result,
          attributeSpecs: mapAttributeSpecs,
          specs: mapSpecs
        }

        // Taro.setNavigationBarTitle({
        //   title: detailInfo.goodsName || '商品详情'
        // })
        const selectedSpecOptionObj = {}
        if (specs.length === 1 && attributeSpecOptions.length === 0) {
          const c = specs[0]
          attributeSpecOptions[0] = {
            goodsId: c.goodsId,
            templateSpecId: c.specId,
            templateSpecOptionId: c.specId,
            templateSpecOptionName: '',
            attributeSpecOptionImge: ''
          }
          const onlyOne = attributeSpecOptions[0]
          // templateSpecOptionName为空 默认规格
          if (onlyOne.templateSpecOptionName === '') {
            // TODO:默认名字
            const defaultName = ''
            selectedSpecOptionObj[onlyOne.templateSpecId] = {
              ...onlyOne,
              templateSpecOptionName: defaultName,
              attributeSpecOptionImge: detailInfo.goodsImage
            }
            // detailInfo.attributeSpecs[0].options[0].templateSpecOptionName = defaultName
            detailInfo.specs[0].specName = defaultName
          }
        }

        if (Object.keys(selectedSpecOptionObj).length > 0) {
          yield put({
            type: 'setState',
            payload: {
              detailInfo,
              selectedSpecOptionObj
            }
          })
        } else {
          yield put({
            type: 'setState',
            payload: {
              detailInfo
            }
          })
        }
        // 获取动态图的宽高,需要放在setState基础数据后，放在前面会阻塞基础数据渲染
        // const remarkImages = yield asyncSplitImage(_remarkImages)
        detailInfo.remarkImages = _remarkImages
        yield put({
          type: 'setState',
          payload: {
            detailInfo
          }
        })
      } catch (e) {
        // eslint-disable-next-line no-empty
      } finally {
      }
    }
  },
  reducers: {
    setState(state, { payload }) {
      return { ...state, ...payload }
    }
  }
}
