import { list } from '@/services/mods/goodsCategory/list'
import { page, IParams } from '@/services/mods/goods/page'
export const namespace = 'purchase-module-home'

export interface MenuItem {
  bgImageUrl?: string
  categoryName: string
  id: string
  children?: MenuItem[]
}

export interface IPurchaseHome {
  menus: MenuItem[]
  goodsList: Goods[]
  totalCount: number
  selectedId: string // 一级菜单id
  keywords: string // 查询关键字
  id: string // category id
  page: number
  size: number
}

export const ALL_ID = '-1'
export const initialPageParams = {
  page: 1,
  size: 20
}
const defaultState: IPurchaseHome = {
  menus: [],
  selectedId: null,
  goodsList: null,
  totalCount: 0,
  keywords: '',
  id: null,
  page: initialPageParams.page,
  size: initialPageParams.size
}

type CategoryItem = defs.GoodsCategoryAssembleResponse
export type Goods = defs.GoodsInfoListResponse
// 查找一级分类
function findCategoryByPid(list: MenuItem[], pid: string) {
  for (const item of list) {
    if (item.id === pid) {
      return item
    }
  }
  return null
}
// 格式化菜单分类数据
function formatCategoryList(list: CategoryItem[]) {
  const result = []
  for (const item of list) {
    const { bgImageUrl, categoryName, id, level, pid } = item
    // 一级菜单
    if (level === 1) {
      result.push({
        bgImageUrl,
        categoryName,
        id,
        children: []
      })
      continue
    }
    const parentMenu: MenuItem = findCategoryByPid(result, pid)
    if (!parentMenu) {
      continue
    }
    parentMenu.children.push({
      bgImageUrl,
      categoryName,
      id
    })
  }
  return result
}

export default {
  namespace,
  state: defaultState,
  effects: {
    *queryCategoryList(_, { call, put }) {
      const result: CategoryItem[] = yield call(list)
      yield put({
        type: `setState`,
        payload: {
          menus: formatCategoryList(result)
        }
      })
    },
    *queryGoodsList({ payload: { page: cPage, size, categoryId, goodsName } }, { call, put }) {
      const id = categoryId === ALL_ID ? undefined : categoryId
      const params: IParams = {
        queryParams: {
          page: cPage,
          size,
          categoryId: id,
          goodsName
        }
      }
      try {
        const result: defs.IwubidaPageResult<defs.GoodsInfoListResponse> = yield call(page, params)
        yield put({
          type: 'setState',
          payload: {
            goodsList: result.results,
            totalCount: result.totalCount
          }
        })
      } catch (error) {}
    }
  },
  reducers: {
    setState(state, { payload }) {
      return { ...state, ...payload }
    }
  }
}
