import React, { useEffect, useState } from 'react'
import { Input, Table, Pagination } from 'antd'
import { ListLayout, Content } from '../../layout/list-layout'
import { IAgent, getColumns } from './columns'
import styles from './style.module.scss'
import { IDvaState, namespace } from '@/models/express-manage/list'
import { IDispatch } from '@/models/connect'
import { connect } from 'react-redux'
import { PaginationWrapper, pageSizeOptions, showTotal, defaultPageOptions } from '@/components/PaginationWrapper'
import { usePagination } from '@/pages/hooks/usePagination'
import { useDebounceFn } from '@umijs/hooks'
const Search = Input.Search

interface IProps extends IDvaState, IDispatch {}

const ExpressList: React.FC<IProps> = ({ dispatch, deliveryList, totalCount }) => {
  const [pageOptions, setPagination] = usePagination(defaultPageOptions)
  const [keywords, handleInputChange] = useState<string>()
  const { run: query } = useDebounceFn(() => {
    dispatch({
      type: `${namespace}/queryList`,
      payload: {
        ...pageOptions,
        keywords
      }
    })
  }, 300)
  useEffect(query, [pageOptions.page, pageOptions.size, keywords])
  function handlePageSizeChange(page, size) {
    setPagination({
      page,
      size
    })
  }

  function handleSearchInputChange(e) {
    setPagination({
      page: 1,
      size: pageOptions.size
    })
    handleInputChange(e.target.value)
  }

  return (
    <ListLayout>
      <Search
        style={{ width: 320, marginRight: 10 }}
        placeholder="发货单号/采购单号"
        value={keywords}
        enterButton="查询"
        size="large"
        onSearch={query}
        onChange={handleSearchInputChange}
      />
      {/* <Button type="primary" size="large">
        导出
      </Button> */}

      <Content>
        <Table<IAgent>
          columns={getColumns()}
          dataSource={deliveryList}
          tableLayout="fixed"
          pagination={false}
          className={styles.table}
          rowClassName={() => styles.row}
        />
        <PaginationWrapper>
          <Pagination
            pageSize={pageOptions.size}
            pageSizeOptions={pageSizeOptions}
            current={pageOptions.page}
            onChange={handlePageSizeChange}
            total={totalCount}
            showSizeChanger
            showQuickJumper
            onShowSizeChange={handlePageSizeChange}
            showTotal={showTotal}
          />
        </PaginationWrapper>
      </Content>
    </ListLayout>
  )
}

const mapStateToProps = models => ({
  deliveryList: models[namespace].deliveryList,
  totalCount: models[namespace].totalCount
})

export default connect(mapStateToProps)(ExpressList)
