import { useState, useRef } from 'react'

interface IPagination {
  page: number
  size?: number
}

const defaultPageOptions: IPagination = {
  page: 1,
  size: 10
}

type returned = [IPagination, (pageOptions: IPagination) => void]

export function usePagination(initPageOptions: IPagination = defaultPageOptions): returned {
  const [page, setPage] = useState(initPageOptions.page)
  const [size, setSize] = useState(initPageOptions.size)
  function setPagination(pageOptions: IPagination) {
    setPage(pageOptions.page)
    if (pageOptions.size) {
      setSize(pageOptions.size)
    }
  }
  const pageOptions: IPagination = {
    page,
    size
  }
  return [pageOptions, setPagination]
}

export function useNoRenderPagination(initPageOptions: IPagination = defaultPageOptions): returned {
  const { current } = useRef(initPageOptions)
  function setPagination(pageOptions: IPagination) {
    current.page = pageOptions.page
    if (pageOptions.size) {
      current.size = pageOptions.size
    }
  }
  const pageOptions = current
  return [pageOptions, setPagination]
}
