import React from 'react'
import { Layout, Spin } from 'antd'
import TopHeader from './top-header'
import { IRouteConfig } from '../../router/typing'
import { Route, Switch } from 'react-router-dom'
import { omitRouteRenderProperties } from '../../router/utils'
import { namespace } from '@/models/global'
import { connect } from 'react-redux'
import styles from './style.module.scss'
import SideMenu from '@/menus'
const { Content } = Layout

interface IProps {
  routes: IRouteConfig[]
  loading: boolean
}

interface IState {
  breadcrumbs: string[]
  collapsed: boolean
  tabsList: any
}

const BasicLayout: React.FC<IProps> = ({ loading, routes }) => {
  return (
    <Layout style={{ height: '100vh' }}>
      <SideMenu />
      <Content>
        <TopHeader />
        <div style={{ overflow: 'auto', height: 'calc(100% - 118px)' }} id="pageWrap">
          {loading && (
            <div className={styles.loading}>
              <Spin tip="加载中..." size="large" />
            </div>
          )}
          <Switch>
            {routes.map(route => (
              <Route {...omitRouteRenderProperties(route)} key={route.path} component={route.component} path={route.path} />
            ))}
          </Switch>
        </div>
      </Content>
    </Layout>
  )
}

const mapStateToProps = (models: any) => ({
  loading: models[namespace].loading
})

export default connect(mapStateToProps)(BasicLayout)
