/* eslint-disable react-hooks/exhaustive-deps */
import React, { useEffect } from 'react'
import {
  BellOutlined,
  MenuFoldOutlined,
  MenuUnfoldOutlined,
  CloseOutlined,
  LogoutOutlined,
  ExclamationCircleOutlined
} from '@ant-design/icons'
import imgs from '../../../assets/images'
import styles from './style.module.scss'
import UiBreadcrumb from '../ui-breadcrumb'
import { NavLink, useHistory } from 'react-router-dom'
import Menu, { ClickParam } from 'antd/lib/menu'
import { Dropdown, Modal } from 'antd'
import { IDispatch } from '@/models/connect'
import { namespace } from '@/models/login'
import { namespace as globalNs } from '@/models/global'
import { namespace as sideMenuNs, MenuProps } from '@/models/common/side-menu'
import { namespace as shoppingCartNamespace } from '@/models/global/product-spec'
import { connect } from 'react-redux'

interface IProps extends IDispatch, Partial<MenuProps> {
  userInfo?: any
}
interface IButton {
  text: string
  path: string
  menuCode: string
  handleRemoveTabsList: (code) => void
}

function SpButton(props: any) {
  const { text, path, menuCode, handleRemoveTabsList } = props
  return (
    <NavLink exact className={styles.tabButton} activeClassName={styles.tabButtonActive} to={path}>
      <span>{text}</span>
      <CloseOutlined
        onClick={e => {
          e.preventDefault()
          handleRemoveTabsList(menuCode)
        }}
        className={styles.tabButtonIcon}
      />
    </NavLink>
  )
}
const TopHeader: React.FC<IProps> = props => {
  const history = useHistory()
  useEffect(() => {
    props.dispatch({
      type: `${globalNs}/queryUserInfo`
    })
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [])
  const menuHandlerMap = {
    logout: () => {
      Modal.confirm({
        title: '确定要退出登录吗？',
        icon: <ExclamationCircleOutlined />,
        okText: '确认',
        cancelText: '取消',
        onOk: () => {
          /**
           * 清空购物车
           */
          props.dispatch({
            type: `${shoppingCartNamespace}/clearShoppingCartList`
          })
          props.dispatch({
            type: `${namespace}/logout`,
            payload: {
              active: true
            }
          })
        }
      })
    }
  }

  function handleClick(values: ClickParam) {
    const key = values.key
    menuHandlerMap[key]()
  }
  const userMenus = (
    <Menu style={{ width: 160 }} onClick={handleClick}>
      <Menu.Item key="logout">
        <LogoutOutlined />
        退出登录
      </Menu.Item>
    </Menu>
  )
  function toggleCollapsed() {
    props.dispatch({
      type: `${sideMenuNs}/setState`,
      payload: {
        collapsed: !props.collapsed
      }
    })
  }
  function handleRemoveTabsList(key) {
    const { dispatch, tabsList } = props
    const list: any[] = tabsList.filter(item => key !== item.key)
    if (list.length) {
      history.push(list[list.length - 1].path)
    }
    dispatch({
      type: `${sideMenuNs}/setState`,
      payload: {
        tabsList: list
      }
    })
  }
  const { collapsed, tabsList, userInfo } = props
  return (
    <>
      <div className={styles.topHeader}>
        <div className={styles.ignoreRight}>
          <div>
            {collapsed ? (
              <MenuUnfoldOutlined
                onClick={() => {
                  toggleCollapsed()
                }}
              />
            ) : (
              <MenuFoldOutlined
                onClick={() => {
                  toggleCollapsed()
                }}
              />
            )}

            {tabsList.length > 0 ? (
              <div className={`${styles.inline} ${styles.ml10}`}>
                {tabsList.map(item => (
                  <SpButton
                    key={item.key}
                    handleRemoveTabsList={handleRemoveTabsList}
                    menuCode={item.key}
                    path={item.path}
                    text={item.title}
                  />
                ))}
              </div>
            ) : null}
          </div>
          <div className={styles.userInfo}>
            <BellOutlined style={{ fontSize: '16px', marginRight: '24px' }} />
            <Dropdown overlay={userMenus} placement="bottomLeft">
              <div className={styles.inline}>
                <img className={styles.ignoreHeaderAvatar} src={imgs.Avatar} alt="头像" />
                <span className={styles.headerUserName}>{userInfo.managerName}</span>
              </div>
            </Dropdown>
          </div>
        </div>
      </div>
      <UiBreadcrumb />
    </>
  )
}

const mapStateToProps = models => ({
  userInfo: models[globalNs].userInfo,
  ...models[sideMenuNs]
})

export default connect(mapStateToProps)(TopHeader)
