import React, { useState, useEffect, useRef } from 'react'
import { Card, Button, Empty, Modal, Form, Typography } from 'antd'
import { IDvaState, namespace } from '@/models/order-manage/purchase/commodity-delivery'
import { connect } from 'react-redux'
import { IDispatch } from '@/models/connect'
import { ExclamationCircleOutlined } from '@ant-design/icons'
const { Title } = Typography

const { confirm } = Modal

interface IProps extends Partial<IDvaState>, IDispatch {
  /**已发货信息 */
  sendedData?: defs.OrderDetailSendedResponse
  actionSuccess?: () => void
}
export const DeliveryRecord: React.FC<IProps> = props => {
  const { sendedData, dispatch, actionSuccess } = props
  const data = sendedData
  useEffect(() => {
    initDataSource()
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [data])
  const [form] = Form.useForm()
  const formRef = useRef()
  const [dataSource, setDataSource] = useState([])
  const initDataSource = () => {
    setDataSource(sendedData.goodsInfoResponseList)
  }
  const columns = [
    {
      title: '商品品牌',
      dataIndex: 'brandName',
      width: '30%'
    },
    {
      title: '商品分类',
      dataIndex: 'categoryName'
    },
    {
      title: '商品名称',
      dataIndex: 'goodsName'
    },
    {
      title: '商品类型',
      dataIndex: 'goodsTypeDesc'
    },
    {
      title: '商品编码',
      dataIndex: 'specCode'
    },
    {
      title: '商品规格',
      dataIndex: 'goodsSpec'
    },
    {
      title: '本次发货',
      dataIndex: 'sendedNumber'
    }
  ]
  const onformValueChange = (_, values) => {
    setDataSource(values.sendGoodsRequests)
  }
  /**收货 */
  const receiveAction = () => {
    dispatch({
      type: `${namespace}/receive`,
      payload: { orderLogisticsId: sendedData.orderLogisticsId },
      callback: () => {
        // 成功
        actionSuccess()
      }
    })
  }
  const showConfirm = () => {
    confirm({
      title: '订单收货',
      icon: <ExclamationCircleOutlined />,
      content: '请仔细核对商品，是否确认收货？',
      okText: '确认收货',
      onOk() {
        receiveAction()
      }
    })
  }

  return (
    <Card
      style={{ marginBottom: '24px' }}
      title={`发货记录-${sendedData.statusDesc} (${sendedData.sendCode})`}
      extra={
        sendedData.status === 'deliveried' ? null : (
          <Button
            type="primary"
            onClick={() => {
              showConfirm()
            }}
          >
            收货
          </Button>
        )
      }
    >
      <Form
        form={form}
        name="delivery-record"
        ref={formRef}
        fields={[{ name: 'sendGoodsRequests', value: dataSource }]}
        onValuesChange={onformValueChange}
      >
        <div className="ant-table ant-table-bordered">
          <div className="ant-table-container">
            <div className="ant-table-content">
              <table style={{ tableLayout: 'auto' }}>
                <thead>
                  <tr>
                    {columns.map((v, i) => (
                      <th className="ant-table-cell" key={i}>
                        {v.title}
                      </th>
                    ))}
                  </tr>
                </thead>
                <tbody className="ant-table-tbody">
                  {dataSource.length === 0 ? (
                    <tr className="ant-table-placeholder">
                      <td colSpan={7} className="ant-table-cell">
                        <Empty />
                      </td>
                    </tr>
                  ) : (
                    <Form.List name="sendGoodsRequests">
                      {fields =>
                        fields.map(field => (
                          <tr className="ant-table-row" key={`wrap_${field.key}`}>
                            {/* 商品品牌 */}
                            <td className="ant-table-cell">{dataSource[field.fieldKey]?.brandName}</td>
                            {/* 商品分类 */}
                            <td className="ant-table-cell">{dataSource[field.fieldKey]?.categoryName}</td>
                            {/* 商品名称 */}
                            <td className="ant-table-cell">{dataSource[field.fieldKey]?.goodsName}</td>
                            {/* 商品类型 */}
                            <td className="ant-table-cell">{dataSource[field.fieldKey]?.goodsTypeDesc}</td>
                            {/* 商品编码 */}
                            <td className="ant-table-cell">{dataSource[field.fieldKey]?.specCode}</td>
                            {/* 商品规格 */}
                            <td className="ant-table-cell">{dataSource[field.fieldKey]?.goodsSpec}</td>
                            {/* 本次发货/本次出库 */}
                            <td className="ant-table-cell">{dataSource[field.fieldKey]?.sendedNumber}</td>
                          </tr>
                        ))
                      }
                    </Form.List>
                  )}
                </tbody>
              </table>
            </div>
          </div>
        </div>

        <Title level={4} style={{ marginTop: '12px' }}>
          发货信息
        </Title>
        <Form.Item label="发货单号">
          <span>{data?.sendCode}</span>
        </Form.Item>
        <Form.Item label="物流公司">
          <span>{data?.logisticsProvider}</span>
        </Form.Item>
        <Form.Item label="物流单号">
          <span>{data?.logisticsCode}</span>
        </Form.Item>
        <Form.Item label="发货时间">
          <span>{data?.sendTime}</span>
        </Form.Item>
        {sendedData.status === 'deliveried' ? (
          <Form.Item label="收货时间">
            <span>{data?.receiversTime}</span>
          </Form.Item>
        ) : null}
      </Form>
    </Card>
  )
}
const mapStateToProps = models => ({})

export default connect(mapStateToProps)(DeliveryRecord)
