import React, { useRef } from 'react'
import { Modal, Form, Input, DatePicker } from 'antd'
import dayjs from 'dayjs'
interface ModalProps {
  visible: boolean
  handleCancel: () => void
  handleOk: (value) => void
}
const layout = {
  labelCol: { span: 5 },
  wrapperCol: { span: 17 }
}
const ModalForm: React.FC<ModalProps> = ({ visible, handleCancel, handleOk }) => {
  const [form] = Form.useForm()
  const formRef = useRef()
  const onOk = async () => {
    try {
      const { dateTime, ...resData } = await form.validateFields()
      if (resData) {
        handleOk({ ...resData, dateTime: dayjs(dateTime).format('YYYY-MM-DD HH:mm:ss') })
      }
    } catch (errorInfo) {
      return false
    }
  }

  return (
    <Modal title="订单发货" visible={visible} onOk={onOk} onCancel={handleCancel} okText="发货" cancelText="取 消">
      <Form {...layout} form={form} name="send_goods" ref={formRef}>
        <Form.Item
          name="dateTime"
          label="发货时间"
          rules={[
            {
              required: true,
              message: '请输入发货时间'
            }
          ]}
        >
          <DatePicker format={'YYYY-MM-DD HH:mm:ss'} showTime />
        </Form.Item>
        <Form.Item name="logisticsCompanyName" label="物流公司">
          <Input placeholder="请输入物流公司" />
        </Form.Item>
        <Form.Item name="logisticsOrderId" label="物流单号">
          <Input placeholder="请输入物流单号" />
        </Form.Item>
        <Form.Item name="remark" label="备注">
          <Input.TextArea rows={4} placeholder="请输入备注" />
        </Form.Item>
      </Form>
    </Modal>
  )
}
export default ModalForm
