import React, { useEffect, useState } from 'react'
import { Tabs, Card, Descriptions, Popover } from 'antd'
import { IDispatch } from '@/models/connect'
import { ExclamationCircleOutlined } from '@ant-design/icons'
import { namespace, IState } from '@/models/order-manage/purchase/detail'
import { connect } from 'react-redux'
import OrderInfo from './components/order-info'
import OrderInfoStatus from './components/order-info-status'
import SingerLineCards from './components/single-line-cards'
import GoodsInfo from './components/goods-info'
import DescItem from './components/desc-item'
import styles from './style.module.scss'
import { useLocation } from 'react-router-dom'
import { covertSearch2Obj } from '@/utils'
import FooterActionBar from './components/footer-action-bar'
import { StatusSteper } from './components/status-steper'
import CommodityDelivery from './commodity-delivery'
const { TabPane } = Tabs
const { Item } = Descriptions

const orderDetailTabKey = 'orderDetail'
const goodsSendTabKey = 'goodsSend'

interface IProps extends IState, IDispatch {}

const OrderManageDetail: React.FC<IProps> = props => {
  const { dispatch, baseInfo, discountInfo, goodsInfo, invoiceInfo, orderStatus, customerInfo } = props
  const [tabKey, setTabKey] = useState<string>(orderDetailTabKey)
  const sellerInfo = customerInfo.sellerInfo || {}
  const location = useLocation()
  useEffect(() => {
    const temp: any = covertSearch2Obj(location.search)
    const tab = temp.tab
    if (Number(tab) === 2) {
      setTabKey(goodsSendTabKey)
    } else {
      setTabKey(orderDetailTabKey)
    }
    queryData()
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [])
  const queryData = () => {
    const temp: any = covertSearch2Obj(location.search)
    if (temp.orderId && typeof temp.orderId !== 'undefined') {
      dispatch({
        type: `${namespace}/init`,
        payload: { orderId: temp.orderId }
      })
    }
  }
  return (
    <section className={styles.container}>
      <Tabs
        tabBarGutter={33}
        tabBarStyle={{ paddingLeft: '25px' }}
        onChange={activeKey => {
          setTabKey(activeKey)
        }}
        defaultActiveKey={orderDetailTabKey}
        activeKey={tabKey}
      >
        <TabPane tab="订单详情" key={orderDetailTabKey}>
          <StatusSteper resp={baseInfo.mainStatus} />
          <OrderInfo info={baseInfo} />
          <Tabs tabBarGutter={33} tabBarStyle={{ paddingLeft: '25px' }} defaultActiveKey="1">
            <TabPane tab="订单信息" key="1">
              <section className={styles.sectionBody}>
                <OrderInfoStatus orderInfo={orderStatus} />
                <SingerLineCards
                  left={
                    <Card title="订单金额">
                      <Descriptions column={2}>
                        <Item label="应付金额">
                          <span className={styles.specText}>￥{Number(baseInfo.amountPayable).toFixed(2)}</span>（税率
                          {baseInfo.taxRate}
                          %）
                        </Item>
                        <Item label="商品原价">￥{Number(baseInfo.originalPrice).toFixed(2)}</Item>
                        <Item label="已付金额">￥{Number(baseInfo.amountPaid).toFixed(2)}</Item>
                        <Item label="订单优惠">
                          ￥{Number(baseInfo.preferentialPrice).toFixed(2)}
                          <Popover
                            title="优惠详情"
                            content={
                              <div style={{ display: 'inline-block', maxWidth: '150px' }}>
                                <Descriptions column={1}>
                                  {discountInfo && discountInfo.length
                                    ? discountInfo.map((di, index) => (
                                        <Descriptions.Item key={index} label={di.discountsTypeDesc}>
                                          ￥{di.preferentialPrice}
                                        </Descriptions.Item>
                                      ))
                                    : null}
                                </Descriptions>
                              </div>
                            }
                          >
                            <ExclamationCircleOutlined className={styles.detailIcon} style={{ marginLeft: '8px' }} />
                          </Popover>
                        </Item>
                        <Item label="待付金额">
                          <span className={styles.redText}>￥{Number(baseInfo.balanceDue).toFixed(2)}</span>
                        </Item>
                        <Item label="本单收取平台服务费">￥{Number(baseInfo.servicePrice).toFixed(1)}</Item>
                      </Descriptions>
                    </Card>
                  }
                  right={
                    <Card title="支付信息">
                      <Descriptions column={2}>
                        <Item label="支付金额">￥{Number(baseInfo.payAmount).toFixed(2)}</Item>
                        <Item label="支付状态">{baseInfo.payStatusDesc}</Item>
                        <Item label="支付方式">{baseInfo.payWayDesc}</Item>
                        <Item label="支付渠道">{baseInfo.payChannelDesc}</Item>
                      </Descriptions>
                    </Card>
                  }
                />
                <Card title="供应商信息">
                  <Descriptions column={2}>
                    <Item label="商家名称">{sellerInfo.memberName}</Item>
                    <Item label="商家类型">{sellerInfo.memberTypeDesc}</Item>
                    <Item label="联系方式">{sellerInfo.mobile}</Item>
                    <Item label="商家编号">{sellerInfo.id}</Item>
                  </Descriptions>
                  <DescItem label="联系地址">
                    {sellerInfo.provinceName} {sellerInfo.cityName}
                    {sellerInfo.districtName}
                    {sellerInfo.address}
                  </DescItem>
                </Card>
                <SingerLineCards
                  left={
                    <Card title="发票信息">
                      <Descriptions column={2}>
                        <Item label="发票状态">{invoiceInfo.statusDesc}</Item>
                        <Item label="发票类型">{invoiceInfo.typeDesc}</Item>
                      </Descriptions>
                      <Descriptions column={1}>
                        <Item label="发票抬头">{invoiceInfo.title}</Item>
                        <Item label="发票内容">{invoiceInfo.content}</Item>
                      </Descriptions>
                      <DescItem label="发票明细">
                        {invoiceInfo.identifyNumber} / {invoiceInfo.unitAddress} / {invoiceInfo.mobile} / {invoiceInfo.bank}
                      </DescItem>
                    </Card>
                  }
                  right={
                    <Card title="物流信息">
                      <DescItem align="right" label="物流方式">
                        {baseInfo.wayDesc}
                      </DescItem>
                      <DescItem align="right" label={baseInfo.way === 1 ? '配送信息' : '自提地址'}>
                        {`${baseInfo.receiverName} ${baseInfo.receiverMobile} ` +
                          baseInfo.provinceName +
                          baseInfo.cityName +
                          baseInfo.districtName +
                          baseInfo.receiverAddress}
                      </DescItem>
                    </Card>
                  }
                />
                {/* <div className={styles.center}>
                  <Button onClick={() => history.goBack()}>返回</Button>
                </div> */}
              </section>
            </TabPane>
            <TabPane tab="商品信息" key="2">
              <section className={styles.sectionBody}>
                <GoodsInfo list={goodsInfo} />
                {/* <div className={styles.center}>
                  <Button onClick={() => history.goBack()}>返回</Button>
                </div> */}
              </section>
            </TabPane>
          </Tabs>
        </TabPane>
        <TabPane tab="商品收货" key={goodsSendTabKey}>
          <StatusSteper resp={baseInfo.mainStatus} />
          <CommodityDelivery
            onActionSuccess={() => {
              queryData()
            }}
          />
        </TabPane>
      </Tabs>
      <FooterActionBar />
    </section>
  )
}

const mapStateToProps = models => ({
  baseInfo: models[namespace].baseInfo,
  logisticsInfo: models[namespace].logisticsInfo,
  discountInfo: models[namespace].discountInfo,
  goodsInfo: models[namespace].goodsInfo,
  invoiceInfo: models[namespace].invoiceInfo,
  orderStatus: models[namespace].orderStatus,
  customerInfo: models[namespace].customerInfo
})

export default connect(mapStateToProps)(OrderManageDetail)
