import React from 'react'
import { IProductSpecItem } from '@/models/global/product-spec'
import { formatMoney } from '@/utils/tools'
import _ from 'lodash'
import { Dropdown, Menu } from 'antd'
interface IProps {
  selectedProductSpectList: IProductSpecItem[]
}
export function MoneyShowComponent(props: IProps) {
  const groupByList = _.groupBy<IProductSpecItem>(props.selectedProductSpectList, 'moneySymbol')
  const groupByReduceMap = {}
  Object.keys(groupByList).forEach(key => {
    const item = groupByList[key]
    const total = item.reduce<number>((preV, current) => {
      const total = preV + Number(current.price) * Number(current.selectedCount)
      return total
    }, 0)
    groupByReduceMap[key] = total
  })
  const keys = Object.keys(groupByReduceMap)
  const menu = (
    <Menu>
      {keys.map((key, index) => {
        return (
          <Menu.Item key={index}>
            <ShowItem symbol={key} value={groupByReduceMap[key]} />
          </Menu.Item>
        )
      })}
    </Menu>
  )
  if (keys.length === 0) {
    return <>0</>
  }
  if (keys.length === 1) {
    return <ShowItem symbol={keys[0]} value={groupByReduceMap[keys[0]]} />
  }
  return (
    <Dropdown overlay={menu}>
      {/* eslint-disable-next-line jsx-a11y/anchor-is-valid */}
      <a>查看详情</a>
    </Dropdown>
  )
}

const ShowItem = (props: { symbol: string; value: string }) => {
  const style: React.CSSProperties = {
    marginRight: 40,
    fontSize: 16,
    fontWeight: 'bold',
    color: '#B80821'
  }
  return (
    <>
      <span style={style}>
        {props.symbol}
        {formatMoney(props.value)}
      </span>
    </>
  )
}
