/* eslint-disable jsx-a11y/anchor-is-valid */
import React, { Component } from 'react'
import { Badge, Drawer, Popconfirm, Button } from 'antd'
import { withRouter, RouteComponentProps } from 'react-router'
import {
  namespace as namespaceProductSpec,
  IProductSpecItem,
  ICurrentChangedSelectedSpec
} from '@/models/global/product-spec/index'
import * as Images from '@/assets/images/index'
import { connect } from 'react-redux'
import { formatMoney } from '@/utils/tools/index'
import styles from './index.module.scss'
import { MoneyShowComponent } from '../../MoneyShowComponent'
import { SHOPPING_CART } from '@/router/config/purchase-module/path'
import { QuestionCircleOutlined, ShoppingCartOutlined } from '@ant-design/icons'

interface IProps extends RouteComponentProps {
  childRef?: any
  dispatch?: any
  selectedProductSpectList?: IProductSpecItem[]
  /* 当前操作的商品 */
  currentChangedSelectedSpec?: ICurrentChangedSelectedSpec
}
interface IStates {
  visible: boolean
}
class Index extends Component<IProps, IStates> {
  constructor(props) {
    super(props)
    this.state = {
      visible: false
    }
  }
  componentDidMount() {
    const { childRef } = this.props
    if (childRef) {
      childRef(this)
    }
    // 监听 localstorage 变化
    window.addEventListener('storage', () => {
      this.props.dispatch({
        type: `${namespaceProductSpec}/refreshList`
      })
    })
  }
  componentWillUnmount() {
    const { childRef } = this.props
    if (childRef) {
      childRef(undefined)
    }
  }
  onCloseDrawer = () => {
    this.setState({
      visible: false
    })
  }
  onOpenDrawer = () => {
    const params = new URLSearchParams(this.props.history.location.search)
    const editOrderId = params.get('editOrderId')
    if (editOrderId) {
      this.handleGoShoppingCart()
    }
    this.setState({
      visible: true
    })
  }
  /* 获取购物车数量和总价 */
  getShoppingCartAmountAndPrice = () => {
    const { selectedProductSpectList } = this.props
    let productAmount = 0
    let productTotalPrice = 0
    if (selectedProductSpectList.length > 0) {
      selectedProductSpectList.forEach(item => {
        productAmount += item.selectedCount
        productTotalPrice += Number(item.price) * item.selectedCount
      })
    }
    return {
      productAmount,
      productTotalPrice
    }
  }
  handleDeleteProductSpec = item => {
    this.props.dispatch({
      type: `${namespaceProductSpec}/deleteProductSpecSelected`,
      payload: item
    })
  }
  handleGoShoppingCart = () => {
    const params = new URLSearchParams(this.props.history.location.search)
    const editOrderId = params.get('editOrderId')
    this.props.history.push(editOrderId ? `${SHOPPING_CART}?editOrderId=${editOrderId}` : SHOPPING_CART)
  }
  render() {
    const { visible } = this.state
    const { selectedProductSpectList } = this.props
    const totalAmountAndPrice = this.getShoppingCartAmountAndPrice()
    const shopCartListWrap =
      selectedProductSpectList.length > 0 ? (
        <div className={styles.list_wrap}>
          {selectedProductSpectList.map(item => {
            return (
              <div className={styles.list_item_content} key={`${item.goodsId}${item.specId}`}>
                <img src={item.goodsImage || Images.defalutZSLogo} alt="" className={styles.goods_img} />
                <div className={styles.goods_info}>
                  <div className={styles.title}>{item.goodsName}</div>
                  <div className={styles.desc}>{item.specDesc}</div>
                </div>
                <div className={styles.goods_price_amount}>
                  <div className={styles.price}>
                    {item.moneySymbol}
                    {formatMoney(item.price)}
                  </div>
                  <div className={styles.amount}>X{`${item.selectedCount}`}</div>
                </div>
                <div className={styles.goods_operate}>
                  <Popconfirm
                    title="确定要删除该商品?"
                    placement="bottomRight"
                    onConfirm={() => {
                      this.handleDeleteProductSpec(item)
                    }}
                    icon={<QuestionCircleOutlined style={{ color: 'red' }} />}
                  >
                    <a href="#" className={styles.goods_operate_el}>
                      删除
                    </a>
                  </Popconfirm>
                </div>
              </div>
            )
          })}
        </div>
      ) : (
        <div className={styles.no_data}>暂无商品</div>
      )
    const shoppingCarInfo = (
      <div className={styles.shop_cart_bottom}>
        <div className={styles.bottom_text}>
          数量：<span className={styles.bottom_text_bold}>{totalAmountAndPrice.productAmount}</span>
        </div>
        <div className={`${styles.bottom_text} ${styles.bottom_text_money}`}>
          金额：
          {/* <span>¥</span>
          <span className={`${styles.bottom_text_bold} ${styles.bottom_text_red}`}>
            {formatMoney(totalAmountAndPrice.productTotalPrice)}
          </span> */}
          <MoneyShowComponent selectedProductSpectList={selectedProductSpectList} />
        </div>
        <div className={styles.operate_btn}>
          <Button type="primary" shape="round" className={styles.operate_btn_inner} onClick={this.handleGoShoppingCart}>
            去购物车
          </Button>
        </div>
      </div>
    )
    return (
      <div>
        <div className={styles.ignoreShoppingCart} onClick={this.onOpenDrawer}>
          <Badge count={totalAmountAndPrice.productAmount || 0} offset={[-30, -15]}>
            {/* <Icon type="shopping-cart" className={styles.ignoreCartIcon} /> */}
            <ShoppingCartOutlined className={styles.ignoreCartIcon} />
          </Badge>
        </div>
        <Drawer
          width={720}
          className="shopping-cart-drawer"
          placement="right"
          closable={false}
          onClose={this.onCloseDrawer}
          visible={visible}
        >
          {shopCartListWrap}
          {shoppingCarInfo}
        </Drawer>
      </div>
    )
  }
}

const mapStateToProps = models => ({
  ...models[namespaceProductSpec]
})

export default connect(mapStateToProps)(withRouter(Index))
