import React, { useEffect } from 'react'
import { Row, Col, Tag, Input } from 'antd'
import styles from './style.module.scss'
import { IBrandSingleItem } from '../index'
import imgs from '@/assets/images'

interface IProps {
  /** 分类列表 */
  brandSortList: Array<IBrandSingleItem>
  /**改变事件 */
  onChange: (data) => void
}
const OrderConfirm: React.FC<IProps> = props => {
  const { brandSortList, onChange } = props
  useEffect(() => {
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [])

  // 表头部件
  const headerWidget = (
    <Row className={styles.listTitleBar} align="middle">
      <Col span={12}>
        <span className={styles.goodInfoTitle}>商品信息</span>
      </Col>
      <Col span={4}>
        <span className={styles.titleText}>采购价</span>
      </Col>
      <Col span={3}>
        <span className={styles.titleText}>数量</span>
      </Col>
      <Col span={3}>
        <span className={styles.titleText}>小计</span>
      </Col>
    </Row>
  )
  const getTotalObj = (item: IBrandSingleItem) => {
    const moneySymbol = item.specList.length > 0 ? item.specList[0].moneySymbol : ''
    const totalPrice =
      moneySymbol +
      item.specList
        .map(v => Number(v.price) * v.selectedCount)
        .reduce((total, v) => total + v)
        .toFixed(2)
    const totalNumber = item.specList.map(v => v.selectedCount).reduce((total, v) => total + v)
    return {
      totalPrice,
      totalNumber
    }
  }
  const remarkChange = (value, index) => {
    const obj = JSON.parse(JSON.stringify(brandSortList))
    obj[index].remark = value
    onChange(obj)
  }
  // 商品列表
  const goodsListWidget = () => {
    return (
      <>
        {brandSortList.map((item, index) => {
          const totalObj = getTotalObj(item)
          return (
            <div className={styles.shopBox} key={index}>
              {/* 公司标题栏 */}
              <div className={styles.shopHeaderBox}>
                <span className={styles.shopName}>{item.supplierName}</span>
                <Tag className={styles.payTypeTag}>全额支付</Tag>
              </div>
              {/* 商品列表 */}
              {item.specList.map((v, i) => {
                return (
                  <Row align="middle" className={styles.goodsListBox} key={i}>
                    <Col span={12}>
                      <div className={styles.goodsItemInfo}>
                        <img src={v.goodsImage || imgs.defalutZSLogo} alt="" className={styles.goodsImg} />
                        <div className={styles.goodsInfoText}>
                          <div className={styles.goodsInfoName}>{v.goodsName}</div>
                          <div className={styles.goodsInfoDescription}>{v.specDesc}</div>
                        </div>
                      </div>
                    </Col>
                    <Col span={4}>
                      <div className={styles.goodsItemText}>
                        {v.moneySymbol}
                        {v.price}
                      </div>
                    </Col>
                    <Col span={3}>
                      <div className={styles.goodsItemText}>x{v.selectedCount}</div>
                    </Col>
                    <Col span={3}>
                      <div className={styles.goodsItemTotal}>
                        {v.moneySymbol}
                        {(Number(v.price) * v.selectedCount).toFixed(2)}
                      </div>
                    </Col>
                  </Row>
                )
              })}
              {/* 商品列表底部备注框 */}
              <Row align="middle" className={styles.goodsListRemarkBox}>
                <Col span={12}>
                  <div className={styles.remarkInputWrap}>
                    <label className={styles.remarkLabel}>备注：</label>
                    <Input.TextArea
                      rows={4}
                      placeholder="请输入备注说明200字以内"
                      className={styles.remarkInput}
                      value={item.remark}
                      onChange={e => {
                        remarkChange(e.target.value, index)
                      }}
                    />
                  </div>
                </Col>
                <Col span={3} offset={4}>
                  <div className={styles.goodsListAllNum}>数量：{totalObj.totalNumber}</div>
                </Col>
                <Col span={3}>
                  <div className={styles.goodsListTotalPrice}>小计：{totalObj.totalPrice}</div>
                </Col>
              </Row>
            </div>
          )
        })}
      </>
    )
  }

  return (
    <div className={styles.listWrap}>
      {/* 表头 */}
      {headerWidget}
      {/* 商品列表 */}
      {goodsListWidget()}
    </div>
  )
}

export default OrderConfirm
