import React, { useEffect, useState } from 'react'
import { Button, message, Modal } from 'antd'

import { withRouter, RouteComponentProps } from 'react-router'
import styles from './style.module.scss'
import DeliveryWay from './delivery-way'
import GoodsInfo from './goods-info'
import { IDvaState, namespace } from '@/models/purchase-module/order-confirm'
import { namespace as shoppingCartNamespace } from '@/models/global/product-spec'
import { IDispatch } from '@/models/connect'
import { connect } from 'react-redux'
import { getLocalStorage } from '@/utils/storage/index'
import { IProductSpecItem } from '@/models/global/product-spec/index'
import { ExclamationCircleOutlined } from '@ant-design/icons'
import { PURCHASE_HOME } from '@/router/config/purchase-module/path'
import { PURCHASE_ORDER_LIST } from '@/router/config/order-manage/path'
import imgs from '@/assets/images/index'
interface IProps extends IDvaState, IDispatch, RouteComponentProps {}

export interface IBrandSingleItem {
  sellerBrandName?: string
  sellerBrandId: string
  supplierName?: string
  goodsBrandType?: 'motorbike' | 'parts'
  selfAddress?: string
  remark?: string
  supplierId?: string | number
  /** 物流配送备注 */
  deliveryRemark?: string
  /** 商家自提备注 */
  selfRemark?: string
  specList: Array<IProductSpecItem>
}
/**
 * 将购物车的数据按照 brandId 和 整车配件分类
 */
const extractBrandSingleSortList = selectedProductSpectList => {
  const sellerBrandIdList = []
  // 获取 brandId 列表
  selectedProductSpectList.forEach(item => {
    if (sellerBrandIdList.indexOf(item.sellerBrandId) === -1) {
      sellerBrandIdList.push(item.sellerBrandId)
    }
  })

  // 按照 brandId 进行分类
  const brandSingleSortList: Array<IBrandSingleItem> = []
  sellerBrandIdList.forEach(item => {
    const tempGoodsList = selectedProductSpectList.filter(itemGoods => itemGoods.sellerBrandId === item)
    if (tempGoodsList.length > 0) {
      brandSingleSortList.push({ sellerBrandId: item, specList: tempGoodsList })
    }
  })

  // 按照 brandType 进行分类（整车还是配件）
  const brandSingleSortFinalList: Array<IBrandSingleItem> = []
  brandSingleSortList.forEach(item => {
    // 获取整车
    const tempGoodsMotorbikeList = item.specList.filter(itemGoods => itemGoods.goodsBrandType === 'motorbike')
    if (tempGoodsMotorbikeList.length > 0) {
      brandSingleSortFinalList.push({
        sellerBrandId: item.sellerBrandId,
        goodsBrandType: 'motorbike',
        sellerBrandName: tempGoodsMotorbikeList[0].sellerBrandName,
        supplierName: tempGoodsMotorbikeList[0].supplierName,
        specList: tempGoodsMotorbikeList,
        supplierId: tempGoodsMotorbikeList[0].supplierId,
        remark: ''
      })
    }
    // 获取配件
    const tempGoodsPartsbikeList = item.specList.filter(itemGoods => itemGoods.goodsBrandType === 'parts')
    if (tempGoodsPartsbikeList.length > 0) {
      brandSingleSortFinalList.push({
        sellerBrandId: item.sellerBrandId,
        goodsBrandType: 'parts',
        sellerBrandName: tempGoodsPartsbikeList[0].sellerBrandName,
        supplierName: tempGoodsPartsbikeList[0].supplierName,
        specList: tempGoodsPartsbikeList,
        supplierId: tempGoodsMotorbikeList[0].supplierId,
        remark: ''
      })
    }
  })
  return brandSingleSortFinalList
}
const OrderConfirm: React.FC<IProps> = props => {
  const { lastAddressId, dispatch, addressList, history } = props
  const [deliveryId, setDeliveryId] = useState<string>('')
  const [modalVisible, setModalVisible] = useState(false)
  const [brandSortList, setBrandSortList] = useState([])
  const selectedProductSpectList = JSON.parse(getLocalStorage('selectedOrderProductSpectList') || '[]') || []
  useEffect(() => {
    dispatch({
      type: `${namespace}/init`
    })
    setBrandSortList(extractBrandSingleSortList(selectedProductSpectList))
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [])
  const moneySymbol = selectedProductSpectList.length > 0 ? selectedProductSpectList[0].moneySymbol : ''
  const totalMoney =
    selectedProductSpectList.length > 0
      ? moneySymbol +
        selectedProductSpectList
          .map(v => Number(v.price) * v.selectedCount)
          .reduce((total, v) => total + v)
          .toFixed(2)
      : 0
  const totalNumber =
    selectedProductSpectList.length > 0 ? selectedProductSpectList.map(v => v.selectedCount).reduce((total, v) => total + v) : 0
  useEffect(() => {
    setDeliveryId(lastAddressId)
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [lastAddressId])
  // 下单
  const submitOrder = () => {
    Modal.confirm({
      title: '确认提交订单?',
      icon: <ExclamationCircleOutlined />,
      okText: '确认',
      cancelText: '取消',
      onOk: () => {
        const currentAddress = addressList.find(v => v.id === deliveryId)
        if (!currentAddress?.id) {
          message.error('请选择收货地址')
          return false
        }
        const payload = {
          receiversUserName: currentAddress.contact,
          receiversMobile: currentAddress.mobile,
          receiversAddressId: currentAddress.id,
          goodsRequests: brandSortList.map(v => ({
            customerId: v.supplierId,
            remark: v.remark,
            specRequestList: v.specList.map(item => ({ number: item.selectedCount, specId: item.specId }))
          }))
        }
        dispatch({
          type: `${namespace}/createOrder`,
          payload,
          callback: () => {
            // 提交成功
            setModalVisible(true)
          }
        })
      }
    })
  }
  const resetCartList = () => {
    dispatch({
      type: `${shoppingCartNamespace}/clearShoppingCartList`
    })
  }
  // 继续采购
  const goHome = () => {
    resetCartList()
    history.push(PURCHASE_HOME)
  }
  // 查看订单详情
  const goOrderDetail = () => {
    resetCartList()
    history.push(PURCHASE_ORDER_LIST)
  }
  // 底部bar
  const footerBar = (
    <div className={styles.footerBar}>
      <div className={styles.totalNum}>总数量：{totalNumber}</div>
      <div className={styles.totalMoney}>
        总价：<span>{totalMoney}</span>
      </div>
      <Button
        type="primary"
        className={styles.orderBtn}
        onClick={() => {
          submitOrder()
        }}
      >
        下单
      </Button>
    </div>
  )
  return (
    <div className={styles.container}>
      <div className={styles.pageContent}>
        {/* 配送地址 */}
        <DeliveryWay currentId={deliveryId} onChange={setDeliveryId} addressList={addressList} />
        {/* 商品列表 */}
        <GoodsInfo brandSortList={brandSortList} onChange={setBrandSortList} />
      </div>
      {/* 底部bar */}
      {footerBar}
      <Modal
        title="提交成功"
        onCancel={() => setModalVisible(false)}
        visible={modalVisible}
        closable={false}
        maskClosable={false}
        footer={
          <div className={styles.footerWrap}>
            <Button
              onClick={() => {
                goHome()
              }}
            >
              继续采购
            </Button>
            <Button
              type="primary"
              onClick={() => {
                goOrderDetail()
              }}
            >
              查看订单
            </Button>
          </div>
        }
      >
        <div className={styles.modalContent}>
          <img src={imgs.Success} alt="" className={styles.successIcon} />
          <p>订单提交成功</p>
        </div>
      </Modal>
    </div>
  )
}

const mapStateToProps = models => {
  return {
    ...models[namespace]
  }
}
export default connect(mapStateToProps)(withRouter(OrderConfirm))
