import React, { Component } from 'react'
import { Card } from 'antd'
import { withRouter, RouteComponentProps } from 'react-router'
import { IDvaState, namespace } from '@/models/purchase-module/product-detail'
import { IDispatch } from '@/models/connect'
import { connect } from 'react-redux'
import styles from './style.module.scss'
import Slider from 'react-slick'
import SpecList from './components/spec-list'
import { findUniqSpec } from './tools'
import { Tabs, message } from 'antd'
import ProductSpec from '@/components/ProductSpec'
import ShoppingCart from '@/pages/purchase-module/components/shopping-cart-bottom'
import { IProductSpecItem } from '@/models/global/product-spec'

const { TabPane } = Tabs

interface IProps extends IDvaState, IDispatch, RouteComponentProps {
  selectedSpecOptionObj: {
    [key: string]: any
  }
}
interface IState {
  brandType: string
  currentHoverImage: string
  productSpecPackage: any
}
class Index extends Component<IProps, IState> {
  state: IState = {
    brandType: 'motorbike',
    currentHoverImage: null,
    productSpecPackage: null
  }
  componentDidMount() {
    const params = new URLSearchParams(this.props.history.location.search)
    const id = params.get('id') || 4332
    const brandType = params.get('brandType') || 'motorbike'
    this.setState({
      brandType
    })
    this.props.dispatch({
      type: `${namespace}/query`,
      payload: {
        id
      }
    })
  }
  componentWillUnmount() {
    this.props.dispatch({
      type: `${namespace}/setState`,
      payload: {
        selectedSpecOptionObj: {}
      }
    })
  }
  handleSelectSpec = ({ selectedSpecOption, isCancel }) => {
    // 点击一个规格option，需要动态去更新未选择的attributeSpecs中的其他spec的可选状态
    // 根据当前选择和之前已经选择属性的规格组合，查询未选择的属性下面的spec的可选状态
    const { templateSpecId } = selectedSpecOption
    const { selectedSpecOptionObj, detailInfo } = this.props
    const { attributeSpecs, attributeSpecOptions, specs } = detailInfo
    if (isCancel) {
      delete selectedSpecOptionObj[templateSpecId]
    } else {
      selectedSpecOptionObj[templateSpecId] = selectedSpecOption
    }
    const selectedKeys = Object.keys(selectedSpecOptionObj)

    const len = specs.length
    // 先过滤掉已经选择了的属性的所有规格
    // 找出所有规格一一与选择了的规格然后在specs中查询是否存在，
    // 存在的话，状态就是可以选择，不存在，则不可以选择

    const filterSelectedOptions = selectedKeys.map(key => selectedSpecOptionObj[key])
    const remainOptions = attributeSpecOptions.map(item => {
      // 如果遍历到的规格所在的属性 在之前有选择的规格中 属于同一个属性，
      // 需要先过滤之前选择的规格，然后再加入对比数组
      // 对比数组
      const tt = [
        ...filterSelectedOptions.filter(it => it.templateSpecId !== item.templateSpecId).map(it => it.templateSpecOptionId),
        // templateSpecOptionId,
        item.templateSpecOptionId
      ]

      // tslint:disable-next-line: no-increment-decrement
      for (let i = 0; i < len; i++) {
        // specOptionCode as  '1,2,3,6,7'
        const { specOptionCode } = specs[i]
        // 转化为数组，templateSpecOptionIds数组,
        const it = specOptionCode.split(',')
        if (tt.every(p => Boolean(it.find(q => q === p)))) {
          // 找到就说明当前遍历的规格与选择的规格的组合是存在的， 说明可以选择
          // console.log(filterSelectedOptions, tt, 'true')
          return {
            ...item,
            canSelect: true
          }
        }
      }
      // console.log(filterSelectedOptions, tt, 'false')
      return {
        ...item,
        canSelect: false
      }
    })
    // remainOptions：剩下的所有规格的状态
    //
    const mapAttribute = attributeSpecs.map(item => {
      const mapOptions = (item as any).options.map(it => {
        const option = remainOptions.find(r => r.templateSpecOptionId === it.templateSpecOptionId)
        if (option) {
          return {
            ...it,
            canSelect: option.canSelect
          }
        }
        return {
          ...it
        }
      })
      return {
        ...item,
        options: mapOptions
      }
    })
    const tmp = JSON.parse(JSON.stringify(selectedSpecOptionObj))
    this.props.dispatch({
      type: `${namespace}/setState`,
      payload: {
        selectedSpecOptionObj: { ...tmp },
        detailInfo: {
          ...detailInfo,
          attributeSpecs: mapAttribute
        }
      }
    })
  }
  onRefAddShoppingCar = ref => {
    this.setState({ productSpecPackage: ref })
  }
  // 加入购物车
  handleAddShoppingCar = () => {
    const { selectedSpecOptionObj } = this.props
    const uniqSpec = findUniqSpec(this.props) || {}
    if (JSON.stringify(selectedSpecOptionObj) === '{}' || JSON.stringify(uniqSpec) === '{}') {
      message.error('请选择商品规格', 2)
      return
    }
    this.state.productSpecPackage.handleAddShoppingCart()
  }
  render() {
    const { detailInfo, selectedSpecOptionObj } = this.props
    const selectedSpecOptionArrs = Object.keys(selectedSpecOptionObj).map(key => selectedSpecOptionObj[key])
    const settings = {
      dots: false,
      infinite: false,
      speed: 500,
      slidesToShow: 5,
      slidesToScroll: 5
    }
    const { minBuyCount } = detailInfo
    const uniqSpec = findUniqSpec(this.props) || {}
    let attributeSpecOptionImge = detailInfo.goodsImage
    // 取到第一个规格对象Id
    // const firstKey = Object.keys(selectedSpecOptionObj)[0]
    const templateSpecOption = selectedSpecOptionArrs.filter(it => it.attributeSpecOptionImge)
    // 取到第一个对象的图片属性
    if (templateSpecOption) {
      const firstAttributeSpecOption = templateSpecOption[0]
      if (firstAttributeSpecOption) {
        attributeSpecOptionImge = firstAttributeSpecOption.attributeSpecOptionImge || detailInfo.goodsImage
      }
    }

    const hasSelectAttribute = Object.keys(uniqSpec).length
    // 设置最小起购数量
    if (hasSelectAttribute && uniqSpec.quantity < minBuyCount) {
      uniqSpec.quantity = minBuyCount
    }
    let noSpec = false
    let currentSelectProduct: IProductSpecItem
    if (detailInfo.attributeSpecOptions.length === 1) {
      const onlyProduct = detailInfo.attributeSpecOptions[0]
      if (onlyProduct.templateSpecOptionName === '') {
        noSpec = true
      }
    }
    if (uniqSpec.specId) {
      currentSelectProduct = {
        goodsId: detailInfo.goodsId as any,
        goodsImage: attributeSpecOptionImge,
        goodsName: detailInfo.goodsName,
        selectedCount: 0,
        specId: uniqSpec.specId,
        price: uniqSpec.purchasePrice as any,
        specDesc: uniqSpec.specName,
        goodsBrandType: this.state.brandType,
        minByCount: detailInfo.minBuyCount,
        goodsBrandId: detailInfo.goodsBrandId as any,
        supplierName: detailInfo.supplierName,
        sellerBrandId: detailInfo.sellerBrandId as any,
        sellerBrandName: detailInfo.sellerBrandName,
        moneySymbol: detailInfo.moneySymbol,
        supplierId: detailInfo.supplierId
      }
    }
    const specsImages = detailInfo.attributeSpecOptions.map(it => it.attributeSpecOptionImge).filter(it => it)
    const sliderImages = [...detailInfo.carousel, ...specsImages]
    return (
      <Card bordered={false}>
        <div className={styles.container}>
          <div className={styles.productIntroWrapper}>
            <div className={styles.previewWrapper}>
              <div className={styles.previewMianImageWrapper}>
                <img src={this.state.currentHoverImage || attributeSpecOptionImge} alt="" />
              </div>
              <div className={styles.previewCarouselWrapper}>
                <Slider {...settings}>
                  {sliderImages.map((item, key) => {
                    return (
                      <div
                        className={styles.previewCarouselItemWrapper}
                        onMouseEnter={() => {
                          this.setState({
                            currentHoverImage: item
                          })
                        }}
                        onMouseLeave={() => {
                          this.setState({
                            currentHoverImage: null
                          })
                        }}
                        key={key}
                      >
                        <img src={item} alt="" />
                      </div>
                    )
                  })}
                </Slider>
              </div>
            </div>
            <div className={styles.specWrapper}>
              <div className={styles.specTitle}>{detailInfo.goodsName} </div>
              <p className={styles.supplierName}>
                {/* <img src={Images.supplierIcon} className={styles.supplierNameImg} alt="supplierName" /> */}
                <div className={styles.supplierNameLabel}>供应商</div>
                <span className={styles.supplierNameText}>{detailInfo.supplierName}</span>
              </p>
              <p className={styles.rowWrapper}>
                <div className={styles.specZhiDaoPriceLable}>零售指导价</div>
                <div className={styles.specZhiDaoPriceText}>
                  {hasSelectAttribute ? uniqSpec.moneySymbol : detailInfo.moneySymbol}
                  {hasSelectAttribute ? uniqSpec.guidePrice : detailInfo.guidePrice}
                </div>
              </p>
              <p className={styles.rowWrapper}>
                <div className={styles.specCaiGouPriceLable}>采购价</div>
                <div className={styles.specCaiGouPriceText}>
                  {hasSelectAttribute ? uniqSpec.moneySymbol : detailInfo.moneySymbol}
                  {hasSelectAttribute ? uniqSpec.purchasePrice : detailInfo.purchasePrice}
                </div>
              </p>

              <div className={styles.specListArea}>
                {noSpec ? null : (
                  <>
                    <SpecList
                      attributeSpecs={detailInfo.attributeSpecs}
                      selectedSpecOptionArrs={selectedSpecOptionArrs}
                      onSelectSpec={this.handleSelectSpec}
                    />
                  </>
                )}
              </div>
              {/* <div className={styles.threeCodeWrapper}>
                {uniqSpec.thirdCode && (
                  <>
                    <span>产品编码:</span>
                    <Alert
                      style={{
                        marginLeft: 10
                      }}
                      message={uniqSpec.thirdCode}
                      type="info"
                      showIcon
                    />
                  </>
                )}
              </div> */}
              {/* {hasSelectAttribute ? ( */}
              <div className={styles.btnWrapper}>
                <div className={styles.steperWrapper}>
                  {/* {uniqSpec.specId ? <ProductSpec productItem={currentSelectProduct} onRef={this.onRefAddShoppingCar} /> : null} */}
                  <ProductSpec productItem={currentSelectProduct} onRef={this.onRefAddShoppingCar} />
                </div>
                <div
                  className={styles.btnGoToShoppingCar}
                  onClick={
                    this.handleAddShoppingCar
                    // () => {
                    // this.props.dispatch(push(routerMenuMappings.menuChildren.shoppingCart.menuProps.routePath))
                    // }
                  }
                >
                  加入购物车
                </div>
              </div>
              {/* ) : (
                <div className={styles.noSelectTip}>*温馨提示：请选择商品规格</div>
              )} */}
            </div>
          </div>
          <div className={styles.productDetail}>
            <Tabs defaultActiveKey="1">
              <TabPane tab="商品介绍" key="1">
                <div
                  className={styles.productDetailText}
                  dangerouslySetInnerHTML={{
                    __html: detailInfo.goodsRemark
                  }}
                ></div>
                {/* <div>
                  {detailInfo.remarkImages.map((item, index) => {
                    return <img src={item} className={styles.specImage} key={index} alt="" />
                  })}
                </div> */}
              </TabPane>
              {detailInfo.basicConf.length > 0 ? (
                <TabPane tab="基础配置" key="2">
                  {detailInfo.basicConf.map((item, index) => {
                    return item.split('\n').map(it => {
                      return (
                        <div key={index} className={styles.productDetailText}>
                          {it}
                        </div>
                      )
                    })
                  })}
                </TabPane>
              ) : null}
            </Tabs>
          </div>
        </div>

        <ShoppingCart />
      </Card>
    )
  }
}
const mapStateToProps = models => {
  return {
    ...models[namespace]
  }
}
export default connect(mapStateToProps)(withRouter(Index))
