import React, { useEffect, useRef, useState } from 'react'
import { namespace, IPurchaseHome, initialPageParams } from '@/models/purchase-module/purchase-home'
import { connect } from 'react-redux'
import { IDispatch } from '@/models/connect'
import GoodsCard from './GoodCard'
import styles from './style.module.scss'
import { Pagination, Empty } from 'antd'
import { pageSizeOptions, showTotal } from '@/components/PaginationWrapper'

interface IProps extends IDispatch, Partial<IPurchaseHome> {}

const Content: React.FC<IProps> = ({ dispatch, goodsList, totalCount, id, keywords, page, size }) => {
  const contentContainer = useRef(null)
  const [cardWidth, setCardWidth] = useState(180)
  function fetchGoodsList(
    page = initialPageParams.page,
    categoryId: string | number = '',
    goodsName = '',
    size = initialPageParams.size
  ) {
    dispatch({
      type: `${namespace}/queryGoodsList`,
      payload: {
        ...initialPageParams,
        page,
        size,
        categoryId,
        goodsName
      }
    })
  }
  function handlePageChange(page, size) {
    dispatch({
      type: `${namespace}/setState`,
      payload: {
        page,
        size
      }
    })
    // eslint-disable-next-line eqeqeq
    const fid = id == undefined ? '' : id
    fetchGoodsList(page, fid, keywords, size)
  }
  useEffect(() => {
    fetchGoodsList()
  }, [])
  useEffect(() => {
    const cardWidth = 190
    function resizeHandler() {
      const width = contentContainer.current ? contentContainer.current.clientWidth - 10 : 0
      if (width) {
        const count = Math.floor(width / cardWidth)
        if (count > goodsList.length) {
          return
        }
        const restMargin = Math.floor((width - count * cardWidth) / count) + 180
        setCardWidth(restMargin)
      }
    }
    resizeHandler()
    window.addEventListener('resize', resizeHandler)
    return () => {
      window.removeEventListener('resize', resizeHandler)
    }
  })
  return (
    <>
      {goodsList && goodsList.length > 0 ? (
        <div ref={contentContainer} className={styles.goodsListWrapper}>
          {goodsList.map(goods => (
            <GoodsCard style={{ width: `${cardWidth}px` }} key={goods.id} goods={goods} />
          ))}
          <div className={styles.paginationWrapper}>
            {/* <Pagination current={page} pageSize={initialPageParams.size} total={totalCount} onChange={handlePageChange} /> */}
            <Pagination
              pageSize={size}
              pageSizeOptions={pageSizeOptions}
              current={page}
              onChange={handlePageChange}
              total={totalCount}
              showSizeChanger
              showQuickJumper
              onShowSizeChange={handlePageChange}
              showTotal={showTotal}
            />
          </div>
        </div>
      ) : null}
      {goodsList && goodsList.length === 0 ? <Empty style={{ marginTop: '100px' }} /> : null}
    </>
  )
}

const mapStateToProps = models => ({
  goodsList: models[namespace].goodsList,
  totalCount: models[namespace].totalCount,
  id: models[namespace].id,
  keywords: models[namespace].keywords,
  page: models[namespace].page,
  size: models[namespace].size
})

export default connect(mapStateToProps)(Content)
