/**
 * brand 单个分类组件，先按照 brandId 分类，然后按照 整车和配件 分类
 */

import React, { Component, Fragment } from 'react'
import { Checkbox, Button } from 'antd'
import { IProductSpecItem } from '@/models/global/product-spec'
import { IBrandSingleItem } from '@/pages/purchase-module/shopping-cart'
import ProductSpec from '@/components/ProductSpec/index'
import { defalutZSLogo } from '@/assets/images'
import { formatMoney } from '@/utils/tools/index'
import './index.scss'

interface IProps {
  /** 分类列表 */
  brandSortList: Array<IBrandSingleItem>
  /** 是否屏蔽操作: 购物车加减 || 操作， 默认 false */
  disableOperate?: boolean
  /** table 选中时的 rowKey  */
  originSelectedRowKey: Array<string>
  /** 当前选中的 selectedRowKeys */
  selectedRowKeys: Array<string>
  /** checkbox change */
  onCheckboxChange?: (operateType: ECheckboxOpreateType, specKeyList: Array<string>) => void
  /** delete specItem */
  onDeleteSpecItem?: (specItem: IProductSpecItem) => void
  /** 是否屏蔽操作: 购物车加减 || 操作， 默认 false */
}

export enum ECheckboxOpreateType {
  checkbox = 'checkbox',
  cancel = 'cancel'
}
class BrandSingleSort extends Component<IProps> {
  /* constructor(props) {
    super(props)
  } */

  specShowItem = (specList: Array<IProductSpecItem>) => {
    const { disableOperate = false, selectedRowKeys } = this.props
    const specListRenderEl = specList.map((item, index) => {
      const specKey = `${item.goodsId}${item.specId}`
      const isChecked = selectedRowKeys.indexOf(specKey) > -1
      return (
        <div className={`product_spec_item ${isChecked ? 'checked' : ''}`} key={index}>
          {!disableOperate && (
            <div className="product_item_brand_checkbox">
              <Checkbox
                checked={this.getSpecCheckboxStatus(item)}
                onChange={e => {
                  this.handSpecCheckboxChange(e, item)
                }}
              />
            </div>
          )}
          <div className="product_item_info_title">
            <img className="product_item_info_img" src={item.goodsImage || defalutZSLogo} alt="product_img" />
            <div className="product_item_info_right_wrap">
              <div className="product_item_goodsname">{item.goodsName}</div>
              <div className="product_item_specdesc">{item.specDesc}</div>
            </div>
          </div>
          <div className="product_item_brand_title">
            {item.moneySymbol}
            {item.price}
          </div>
          <div className="product_item_brand_title">
            <ProductSpec productItem={item} isPlain={false} disable={disableOperate} />
          </div>
          <div className="product_item_brand_title product_item_total_price">
            {item.moneySymbol}
            {formatMoney(Number(item.price) * item.selectedCount)}
          </div>
          {!disableOperate && (
            <div className="product_item_brand_title">
              <Button
                className="product_item_brand_title_remove"
                onClick={() => {
                  this.handleDeleteSpecItem(item)
                }}
              >
                删除
              </Button>
            </div>
          )}
        </div>
      )
    })
    return specListRenderEl
  }

  handleDeleteSpecItem = specItem => {
    if (typeof this.props.onDeleteSpecItem === 'function') {
      this.props.onDeleteSpecItem(specItem)
    }
  }
  /**
   * brandList checkbox
   */
  getBrandListCheckboxStatus = (brandItem: IBrandSingleItem) => {
    const { selectedRowKeys } = this.props
    let specIndexTotal = 0
    brandItem.specList.forEach(item => {
      const specKey = `${item.goodsId}${item.specId}`
      const specIndex = Math.min(selectedRowKeys.indexOf(specKey), 0)
      specIndexTotal += specIndex
    })
    if (specIndexTotal === 0) {
      return true
    }
    return false
  }

  handBrandListCheckboxChange = (e, brandId, brandType) => {
    const { brandSortList, onCheckboxChange } = this.props
    const currentBranidList = brandSortList.filter(item => item.sellerBrandId === brandId && item.goodsBrandType === brandType)
    const currentSpecList = []
    currentBranidList[0].specList.forEach(item => {
      currentSpecList.push(`${item.goodsId}${item.specId}`)
    })

    if (!e.target.checked) {
      // cancel operate
      if (typeof onCheckboxChange === 'function') {
        onCheckboxChange(ECheckboxOpreateType.cancel, currentSpecList)
      }
    } else {
      if (typeof onCheckboxChange === 'function') {
        onCheckboxChange(ECheckboxOpreateType.checkbox, currentSpecList)
      }
    }
  }

  /**
   * 单规格 checkbox 处理
   */
  getSpecCheckboxStatus = (specItem: IProductSpecItem) => {
    const { selectedRowKeys } = this.props
    const specKey = `${specItem.goodsId}${specItem.specId}`
    return selectedRowKeys.indexOf(specKey) > -1
  }

  handSpecCheckboxChange = (e, specItem: IProductSpecItem) => {
    const { onCheckboxChange } = this.props
    const currentSpecList = [`${specItem.goodsId}${specItem.specId}`]
    if (!e.target.checked) {
      // cancel operate
      if (typeof onCheckboxChange === 'function') {
        onCheckboxChange(ECheckboxOpreateType.cancel, currentSpecList)
      }
    } else {
      if (typeof onCheckboxChange === 'function') {
        onCheckboxChange(ECheckboxOpreateType.checkbox, currentSpecList)
      }
    }
  }
  render() {
    const { brandSortList, disableOperate = false } = this.props
    return (
      <Fragment>
        {brandSortList.map((item, index) => {
          return (
            <div className="brand-single-sort-item" key={index}>
              <div className="spec-sort-info">
                {!disableOperate && (
                  <div className="spec-sort-checkbox">
                    <Checkbox
                      checked={this.getBrandListCheckboxStatus(item)}
                      onChange={e => {
                        this.handBrandListCheckboxChange(e, item.sellerBrandId, item.goodsBrandType)
                      }}
                    />
                  </div>
                )}
                <div className="spec-brand-name">{item.supplierName}</div>
              </div>
              {this.specShowItem(item.specList)}
            </div>
          )
        })}
      </Fragment>
    )
  }
}

export default BrandSingleSort
