import React, { Component, Fragment } from 'react'
import { withRouter, RouteComponentProps } from 'react-router'
import { IDispatch } from '@/models/connect'
import { connect } from 'react-redux'
import { ORDER_CONFIRM, PURCHASE_HOME } from '@/router/config/purchase-module/path'
import {
  namespace as namespaceProductSpec,
  IProductSpecItem,
  ICurrentChangedSelectedSpec
} from '@/models/global/product-spec/index'
import { namespace as namespaceShoppingCart } from '@/models/purchase-module/shopping-cart/index'
import { ECheckboxOpreateType } from '@/pages/purchase-module/shopping-cart/components/index'
import { getQueryString } from '@/utils/tools'
import { setLocalStorage } from '@/utils/storage'
import { formatMoney } from '@/utils/tools/index'
import _pullAll from 'lodash/pullAll'
import { Checkbox, Button, Modal } from 'antd'
import customizeModelContent, { ICustomizeModelContent, EnumModelType } from './modelContent'
import BrandSingleSort from './components/index'
import './index.scss'
import style from './index.module.scss'
import { MoneyShowComponent } from '../MoneyShowComponent'

interface IProps extends RouteComponentProps, IDispatch {
  /** 全局购物车数据  */
  selectedProductSpectList: IProductSpecItem[]
  /** 当前操作的商品 */
  currentChangedSelectedSpec: ICurrentChangedSelectedSpec
}

export interface IBrandSingleItem {
  sellerBrandName?: string
  sellerBrandId: string
  supplierName?: string
  goodsBrandType?: 'motorbike' | 'parts'
  selfAddress?: string
  /** 物流配送备注 */
  deliveryRemark?: string
  /** 商家自提备注 */
  selfRemark?: string
  specList: Array<IProductSpecItem>
}
interface IState {
  /** footer width  */
  // cardPosition: ClientRect
  /** 是否屏蔽操作: 购物车加减 || 操作， 默认 false */
  disableOperate?: boolean
  /** 是否是编辑商品 */
  editOrderId: string
  /* 购物车选中的数量 */
  shopoingCartSelectedList: IProductSpecItem[]
  /** 是否隐藏 checkbox，默认 false  */
  hideCheckbox?: boolean
  /* 底部 checkbox 选中状态 */
  footerCheckeIndeterminate: boolean
  /** table 选中时的 rowKey  */
  originSelectedRowKey: Array<string>
  /* 当前选中的 selectedRowKeys */
  selectedRowKeys: Array<string>
  /* 弹窗内容 */
  modelContent: ICustomizeModelContent
  /* 是否弹窗 */
  showModel: boolean
  /* 当前删除 item */
  currentProductItem: IProductSpecItem
}
class ShoppingCartList extends Component<IProps, IState> {
  constructor(props) {
    super(props)
    // 获取全局购物车数据，以及设置选中状态
    const shopoingCartSelectedList = this.props.selectedProductSpectList || []
    const selectedRowKeys = shopoingCartSelectedList.map(item => `${item.goodsId}${item.specId}`)
    const originSelectedRowKey = shopoingCartSelectedList.map(item => `${item.goodsId}${item.specId}`)
    this.state = {
      shopoingCartSelectedList,
      originSelectedRowKey,
      selectedRowKeys,
      showModel: false,
      // cardPosition: document.getElementsByClassName('page_content_height')[0].getBoundingClientRect(),
      disableOperate: Boolean(getQueryString('disableOperate')),
      editOrderId: '',
      hideCheckbox: Boolean(getQueryString('hideCheckbox')),
      footerCheckeIndeterminate: false,
      modelContent: { title: '', content: '', key: '' },
      currentProductItem: null
    }
  }
  componentDidMount() {
    const params = new URLSearchParams(this.props.history.location.search)
    const editOrderId = params.get('editOrderId')
    if (editOrderId) {
      this.setState({ editOrderId })
    }
  }

  componentWillReceiveProps(nextProps) {
    // table 选中时的 rowKey
    const originSelectedRowKey = nextProps.selectedProductSpectList.map(item => `${item.goodsId}${item.specId}`)
    this.setState({
      originSelectedRowKey,
      shopoingCartSelectedList: nextProps.selectedProductSpectList,
      selectedRowKeys: originSelectedRowKey,
      footerCheckeIndeterminate: false
    })
  }

  /**
   * 暂存订单-添加订单
   */
  handleAddGoods = () => {
    const { editOrderId } = this.state
    this.props.history.push(`${PURCHASE_HOME}?editOrderId=${editOrderId}`)
  }
  handleSaveGoods = () => {
    const { shopoingCartSelectedList } = this.state
    const editDetail = shopoingCartSelectedList.map(v => {
      return { quantity: v.selectedCount, specId: v.specId, sellerBrandId: v.sellerBrandId }
    })
    const { editOrderId } = this.state
    this.props.dispatch({
      type: `${namespaceShoppingCart}/editOrderGoodsNum`,
      payload: {
        editDetail,
        orderId: editOrderId
      },
      callback: () => {
        this.props.history.push(ORDER_CONFIRM + '?id=' + editOrderId)
      }
    })
  }

  /**
   * 将购物车的数据按照 brandId 和 整车配件分类
   */
  extractBrandSingleSortList = () => {
    const { selectedProductSpectList = [] } = this.props
    const sellerBrandIdList = []
    // 获取 brandId 列表
    selectedProductSpectList.forEach(item => {
      if (sellerBrandIdList.indexOf(item.sellerBrandId) === -1) {
        sellerBrandIdList.push(item.sellerBrandId)
      }
    })

    // 按照 brandId 进行分类
    const brandSingleSortList: Array<IBrandSingleItem> = []
    sellerBrandIdList.forEach(item => {
      const tempGoodsList = selectedProductSpectList.filter(itemGoods => itemGoods.sellerBrandId === item)
      if (tempGoodsList.length > 0) {
        brandSingleSortList.push({ sellerBrandId: item, specList: tempGoodsList })
      }
    })

    // 按照 brandType 进行分类（整车还是配件）
    const brandSingleSortFinalList: Array<IBrandSingleItem> = []
    brandSingleSortList.forEach(item => {
      // 获取整车
      const tempGoodsMotorbikeList = item.specList.filter(itemGoods => itemGoods.goodsBrandType === 'motorbike')
      if (tempGoodsMotorbikeList.length > 0) {
        brandSingleSortFinalList.push({
          sellerBrandId: item.sellerBrandId,
          goodsBrandType: 'motorbike',
          sellerBrandName: tempGoodsMotorbikeList[0].sellerBrandName,
          supplierName: tempGoodsMotorbikeList[0].supplierName,
          specList: tempGoodsMotorbikeList
        })
      }
      // 获取配件
      const tempGoodsPartsbikeList = item.specList.filter(itemGoods => itemGoods.goodsBrandType === 'parts')
      if (tempGoodsPartsbikeList.length > 0) {
        brandSingleSortFinalList.push({
          sellerBrandId: item.sellerBrandId,
          goodsBrandType: 'parts',
          sellerBrandName: tempGoodsPartsbikeList[0].sellerBrandName,
          supplierName: tempGoodsPartsbikeList[0].supplierName,
          specList: tempGoodsPartsbikeList
        })
      }
    })
    return brandSingleSortFinalList
  }

  /**
   * 处理底部 checkbox 点击
   */
  handleFooterCheckbox = () => {
    const { selectedProductSpectList } = this.props
    const { originSelectedRowKey, shopoingCartSelectedList } = this.state
    const isSelectedAll = shopoingCartSelectedList.length !== selectedProductSpectList.length
    this.setState({
      selectedRowKeys: isSelectedAll ? originSelectedRowKey : [],
      shopoingCartSelectedList: isSelectedAll ? selectedProductSpectList : [],
      footerCheckeIndeterminate: false
    })
  }
  /**
   * 获取已选择的数量以及总价
   */
  getSelectedAmountAndPrice = () => {
    const { shopoingCartSelectedList } = this.state
    if (shopoingCartSelectedList.length > 0) {
      const { currentChangedSelectedSpec, selectedProductSpectList } = this.props
      // 针对于加减操作，获取当前操作的 goodsId, specId，更新 selectedCount
      const currentOperateItem = selectedProductSpectList.find(
        item =>
          String(item.goodsId) === String(currentChangedSelectedSpec.goodsId) &&
          String(item.specId) === String(currentChangedSelectedSpec.specId)
      )
      if (currentOperateItem) {
        shopoingCartSelectedList.map(item => {
          if (
            String(item.goodsId) === String(currentOperateItem.goodsId) &&
            String(item.specId) === String(currentOperateItem.specId)
          ) {
            return (item.selectedCount = currentOperateItem.selectedCount)
          }
          return item
        })
      }

      const totalSlectedAmount = shopoingCartSelectedList.length
      let totalSlectedPrice = 0
      shopoingCartSelectedList.forEach(item => {
        totalSlectedPrice += Number(item.price) * item.selectedCount
      })
      return {
        totalAmount: totalSlectedAmount,
        totalPrice: formatMoney(totalSlectedPrice)
      }
    }
    return {
      totalAmount: 0,
      totalPrice: 0
    }
  }

  /**
   * type: 弹窗类型,deleteItem（单个删除）| deleteByBatch（批量删除）| agentModel（选择代理商）
   * payload
   */
  handleShowModel = (type, payload?) => {
    const modelContent = customizeModelContent.find(item => item.key === type)
    if (type === EnumModelType.deleteItem) {
      const { record } = payload
      this.setState({
        modelContent,
        showModel: true,
        currentProductItem: record
      })
    } else if (type === EnumModelType.deleteByBatch) {
      this.setState({
        modelContent,
        showModel: true
      })
    }
  }

  /**
   * 下单
   */
  handleCreateOrder = () => {
    const { shopoingCartSelectedList } = this.state
    const { dispatch } = this.props
    // 已经勾选的商品
    dispatch({
      type: `${namespaceProductSpec}/setState`,
      payload: {
        selectedOrderProductSpectList: shopoingCartSelectedList
      }
    })
    // 将选中的商品保存在本地
    setLocalStorage('selectedOrderProductSpectList', JSON.stringify(shopoingCartSelectedList))
    this.jumpOrderConfirm()
  }
  jumpOrderConfirm() {
    const orderId = getQueryString('orderId')
    const deliveryAddress = getQueryString('deliveryAddress')
    if (deliveryAddress) {
      this.props.history.push(`${ORDER_CONFIRM}?deliveryAddress=${deliveryAddress}&orderId=${orderId}`)
    } else {
      this.props.history.push(ORDER_CONFIRM)
    }
  }
  /**
   * spec checkbox change
   */
  handleBrandCheckboxChange = (operateType, specKeyList) => {
    const { selectedRowKeys } = this.state
    let tempSelectedRowKeys = JSON.parse(JSON.stringify(selectedRowKeys))
    const { selectedProductSpectList } = this.props
    const shoppingCarLength = this.props.selectedProductSpectList.length // 购物车总数量
    if (operateType === ECheckboxOpreateType.cancel) {
      // 取消勾选
      _pullAll(tempSelectedRowKeys, specKeyList)
    } else {
      tempSelectedRowKeys = tempSelectedRowKeys.concat(specKeyList)
    }
    // 设置购物车数据
    const tempSelectedProductSpectList = selectedProductSpectList.filter(item => {
      return tempSelectedRowKeys.indexOf(`${item.goodsId}${item.specId}`) > -1
    })
    this.setState({
      selectedRowKeys: tempSelectedRowKeys,
      shopoingCartSelectedList: tempSelectedProductSpectList,
      footerCheckeIndeterminate: tempSelectedRowKeys.length !== shoppingCarLength && tempSelectedRowKeys.length !== 0
    })
  }

  /**
   * delete specItem
   */
  handleSpecItem = specItem => {
    this.handleShowModel('deleteItem', { record: specItem })
  }
  handleModelCancel = () => {
    this.setState({
      showModel: false
    })
  }
  handleModelOk = () => {
    const {
      modelContent: { key },
      currentProductItem,
      shopoingCartSelectedList
    } = this.state
    const { dispatch } = this.props
    if (key === EnumModelType.deleteItem) {
      // 删除单条购物车数据
      dispatch({
        type: `${namespaceProductSpec}/deleteProductSpecSelected`,
        payload: currentProductItem
      }).then(res => {
        if (res) {
          // 更新已选择购物车数量
          const shopoingCartSelectedListTemp = shopoingCartSelectedList.filter(
            item => JSON.stringify(item) !== JSON.stringify(currentProductItem)
          )
          this.setState({
            shopoingCartSelectedList: shopoingCartSelectedListTemp,
            showModel: false
          })
        }
      })
    } else if (key === EnumModelType.deleteByBatch) {
      dispatch({
        type: `${namespaceProductSpec}/deleteProductSpecSelectedByBatch`,
        payload: shopoingCartSelectedList
      }).then(res => {
        if (res) {
          this.setState({
            showModel: false
          })
        }
      })
    }
  }
  render() {
    const {
      disableOperate,
      hideCheckbox,
      shopoingCartSelectedList,
      footerCheckeIndeterminate,
      editOrderId,
      originSelectedRowKey,
      selectedRowKeys,
      modelContent,
      showModel
    } = this.state
    const brandSortList = this.extractBrandSingleSortList()
    const selectedAmountAndPrice = this.getSelectedAmountAndPrice()
    const { selectedProductSpectList = [] } = this.props
    const isSelectedProduct = shopoingCartSelectedList.length > 0
    return (
      <div className="shopping_cart_content">
        <div className="shopping_cart_top_header">
          {!disableOperate && (
            <div className="shopping_cart_top_checkbox">
              <Checkbox
                checked={isSelectedProduct}
                indeterminate={footerCheckeIndeterminate}
                disabled={!isSelectedProduct && selectedProductSpectList.length === 0}
                onChange={this.handleFooterCheckbox}
              />
            </div>
          )}

          <div className="product_item_info_title">商品信息</div>
          <div className="product_item_table_header_title">单价</div>
          <div className="product_item_table_header_title">数量</div>
          <div className="product_item_table_header_title">小计</div>
          {!disableOperate && <div className="product_item_table_header_title">操作</div>}
        </div>
        <div className="shopping_cart_body_content">
          <BrandSingleSort
            brandSortList={brandSortList}
            selectedRowKeys={selectedRowKeys}
            originSelectedRowKey={originSelectedRowKey}
            disableOperate={disableOperate}
            onCheckboxChange={(operateType, specKeyList) => {
              this.handleBrandCheckboxChange(operateType, specKeyList)
            }}
            onDeleteSpecItem={specItem => {
              this.handleSpecItem(specItem)
            }}
          />
        </div>
        <div className={style.footer_content}>
          <div className={style.footer_left_wrap}>
            {!hideCheckbox && (
              <Fragment>
                <Checkbox
                  checked={isSelectedProduct}
                  indeterminate={footerCheckeIndeterminate}
                  disabled={!isSelectedProduct && selectedProductSpectList.length === 0}
                  onChange={this.handleFooterCheckbox}
                />
                <span className={style.footer_text}>已选</span>
                <span className={style.footer_selected_num}>({selectedAmountAndPrice.totalAmount})</span>
                {isSelectedProduct ? (
                  <a // eslint-disable-line
                    href="javascript:void(0)" // eslint-disable-line
                    className={style.delete_product}
                    onClick={() => {
                      this.handleShowModel('deleteByBatch')
                    }}
                  >
                    批量删除
                  </a>
                ) : null}
              </Fragment>
            )}
          </div>
          <div className={style.footer_right_wrap}>
            <span className={style.footer_text_sum}>总价：</span>
            {/* <span> ¥ </span>
            <span className={style.footer_total_price}>{selectedAmountAndPrice.totalPrice}</span> */}
            <div className={style.footer_total_price}>
              <MoneyShowComponent selectedProductSpectList={selectedProductSpectList} />
            </div>

            {editOrderId ? (
              <>
                <Button type="primary" className="footer_right_button" onClick={this.handleAddGoods}>
                  添加商品
                </Button>
                <Button
                  type="primary"
                  className="footer_right_button"
                  disabled={!isSelectedProduct}
                  onClick={this.handleSaveGoods}
                >
                  保存修改
                </Button>
              </>
            ) : (
              <div className="footer_right_div">
                <Button
                  type="primary"
                  className="footer_right_button"
                  disabled={!isSelectedProduct}
                  onClick={this.handleCreateOrder}
                >
                  下 单
                </Button>
              </div>
            )}
          </div>
        </div>
        <Modal
          title={modelContent.title}
          visible={showModel}
          cancelText="取消"
          okText="确定"
          onOk={this.handleModelOk}
          onCancel={this.handleModelCancel}
        >
          {modelContent.content}
        </Modal>
      </div>
    )
  }
}

const mapStateToProps = models => ({
  ...models[namespaceProductSpec],
  ...models[namespaceShoppingCart]
})

export default connect(mapStateToProps)(withRouter(ShoppingCartList))
